function calc_alongshore_wavenumber_spectra_vorticity_depthavg(savefolder,simno,Spectime,locx,WL,OL,dt)
% This script will save alongshore transects of velocity.
% INPUT:
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tpos:  start analysis
% tend:  end analysis
% locx:  domain which alongshore wavenumber is being calculated
% WL:    Window length
% OL:    Overlap length
% dt:    length which voriticity is being averaged over
% OUTPUT:
% sim#_alongshore_transect_vel_XX-XXm.mat = offshore spectra at specified domain
% sim#_alongshore_transect_vel_avg_XX-XXm.mat = offshore spectra at specified domain averaged

display('Start save_offshore_spectra.')

%% STEP 1: Load data
load([savefolder,'sim',simno,'_domain.mat']);
% Fvel = matfile([savefolder,'sim',simno,'_vorticity.mat']);
load([savefolder,'sim',simno,'_vorticity.mat']); % loading full in at once

%% STEP 2: Save name

% sname1 = [savefolder,'alongshore_wavenumber_spectra/sim',simno,'_alongshore_transect_vort_',num2str(locx(1)),'-',num2str(locx(end)),'m_tstart',num2str(Spectime(1)),'.mat'];
sname2 = [savefolder,'alongshore_wavenumber_spectra/sim',simno,'_alongshore_wavenumber_vort_spectra_',num2str(locx(1)),'-',num2str(locx(end)),'m_meanremoved.mat'];
sname3 = [savefolder,'alongshore_wavenumber_spectra/sim',simno,'_alongshore_wavenumber_vort_spectra_avg_',num2str(locx(1)),'-',num2str(locx(end)),'m_meanremoved.mat'];

%% STEP 3: Fix domain and pick location 

x = fliplr(900-xp)+50;
y = -244+yp;
dx = 20; % Resolution computing spectra

x_actual = length(x(1,:)); % find the length of x simulation
% x_loc = (length(x(1,:))+1)-x_actual;
for i = 1:length(locx)
    x_loc_frf           = find(x(1,:)==locx(i)); % find the grid location of the cross-shore specified locations
    x_loc_check_frf(i)  = x(1,x_loc_frf); % this is a check to make sure you are saving the right location is chosen in the frf domain
    x_loc_check_sim(i)  = xp(1,x_actual-x_loc_frf); % this is another test to check if the right location is chosen in the simulation domain
    x_loc_sim(i)        = x_actual-x_loc_frf;  % find the grid location in the simulation format
end
x_loc_sim
x_loc_check_frf
x_loc_check_sim

%% STEP 4: Calculate Modeled Spectra
dy      = y(2,1)-y(1,1); % dy in simulation, this is 2 m

for i = 1:length(locx)
	for j = 1:length(Spectime)        
		% vorttemp = squeeze(Fvel.vort(:,x_loc_sim(i),Spectime(j)-((dt/2)-1):Spectime(j)+(dt/2)));
		vorttemp = squeeze(vort(:,x_loc_sim(i),Spectime(j)-((dt/2)-1):Spectime(j)+(dt/2))); % loading all in at once
		%vtemp = squeeze(Fvel.vel_v(:,x_loc_sim(i),Spectime(j)-4:Spectime(j)+4));
		for k = 1:length(vorttemp(:,1,1))
			vortra(k,i,j) = nanmean(squeeze(vorttemp(k,:))); % running avg (ra)
			% CHANGED ALL VORT TO VORTRA SO IT DID NOT REPLACE THE ORIGINAL MATRIX
			%v(k,i,j) = nanmean(squeeze(vtemp(k,:)));
        	end
        % calc spectra for vort runnding avg
        checknans = sum(isnan(vortra(:,i,j)));
        if checknans > 0
            temp = find(~isnan(vortra(:,i,j)));
            display([num2str(checknans),'~NaNs in vortra ',num2str(locx(i)),' time ',num2str(Spectime(i))])
            [Svort(:,i,j),fvort(:,i,j)] = pwelch(vortra(temp,i,j)-nanmean(vortra(temp,i,j)),WL,OL,[],1/dy);  %Uses Welch's periodogram method
        else
            [Svort(:,i,j),fvort(:,i,j)] = pwelch(vortra(:,i,j)-nanmean(vortra(:,i,j)),WL,OL,[],1/dy);  %Uses Welch's periodogram method
        end
    end
    % calc avg spectra over hour
    for m = 1:length(fvort(:,1,1))
        Svort_avg(m,i) = nanmean(squeeze(Svort(m,i,:)));
    end
	display(['cross-shore ',num2str(locx(i)),' m'])
end
f  = squeeze(fvort(:,1,1));

% for i = 1:length(locx) 
%     vort(:,i,:) = squeeze(Fvel.vort(:,x_loc_sim(i),Spectime));%tpos:tend));
% %    v(:,i,:) = squeeze(Fvel.vel_v(:,x_loc_sim(i),Spectime));%tpos:tend));
% end

% process vort
% for i = 1:length(locx)
%     for j = 1:length(Spectime)
%         checknans = sum(isnan(vort(:,i,j)));
%         if checknans > 0
%             temp = find(~isnan(vort(:,i,j)));
%             display([num2str(checknans),'~NaNs in vort ',num2str(locx(i)),' time ',num2str(Spectime(i))])
%             [Svort(:,i,j),f(:,i,j)] = pwelch(vort(temp,i,j),WL,OL,128,1/dy);  %Uses Welch's periodogram method
%         else
%             [Svort(:,i,j),f(:,i,j)] = pwelch(vort(:,i,j),WL,OL,128,1/dy);  %Uses Welch's periodogram method
%         end
%     end
% end



%% STEP 5: Save data
vort_loc = squeeze(vort(:,x_loc_sim(i),3601:end));
writematrix(vort_loc,[savefolder,'S3a_alongshore_vorticity_loc226m_2.csv'],'Delimiter',',')

% eval(['save -v7.3 ',sname1,' vort',' locx',' Spectime'])
eval(['save -v7.3 ',sname2,' Svort',' fvort',' locx',' Spectime',' dt',' dy'])
eval(['save -v7.3 ',sname3,' Svort_avg',' f',' Spectime',' dt',' dy',' locx'])

% mat = [watlev.t u.t v.t vort.t];

% writematrix(mat,[sim19.file.datafolder,'S3a_timeseries.csv'])

display('Done save_offshore_spectra.')

% end
