function calc_alongshore_wavenumber_spectra_vorticity_elev(savefolder,simno,Spectime,WL,OL,dt,resx)
% This script will save alongshore transects of velocity.
% INPUT:
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tpos:  start analysis
% tend:  end analysis
% locx:  domain which alongshore wavenumber is being calculated
% WL:    Window length
% OL:    Overlap length
% dt:    length which voriticity is being averaged over
% resx:  resolution in the cross-shore, just used to load file
% OUTPUT:
% sim#_alongshore_transect_vel_XX-XXm.mat = offshore spectra at specified domain
% sim#_alongshore_transect_vel_avg_XX-XXm.mat = offshore spectra at specified domain averaged

display('Start calc_alongshore_wavenumber_spectra_vorticity_elev.')

%% STEP 1: Load data
% load([savefolder,'sim',simno,'_domain.mat']);
F1 = matfile([savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_resx',num2str(resx),'m.mat']);
vortk_int = squeeze(F1.vort_int);
resx = F1.resx;
resy = F1.resy;
xpt = F1.xpt;
ypt = F1.ypt;
hpt = F1.hpt;
elev = F1.elev;

%% STEP 2: Save name

% sname1 = [savefolder,'alongshore_wavenumber_spectra/sim',simno,'_alongshore_transect_vort_',num2str(locx(1)),'-',num2str(locx(end)),'m_tstart',num2str(Spectime(1)),'.mat'];
sname1 = [savefolder,'alongshore_wavenumber_spectra/sim',simno,'_alongshore_wavenumber_vort_spectra_elev_avg_resx',num2str(resx),'m.mat'];

%% STEP 3: Fix domain and pick location 

xp = fliplr(900-xpt)+50;
yp = -244+ypt;
h = fliplr(hpt);
for i = 1:length(vortk_int(1,1,1,:)) % time steps
    for j = 1:length(elev)
        vortk_int(:,:,j,i)  = -fliplr(squeeze(vortk_int(:,:,j,i)));
    end
end

%% STEP 4: Calculate Modeled Spectra
dy      = yp(2,1)-yp(1,1); % dy in simulation, this is 2 m

% get length of spectra
vorttemp = squeeze(vortk_int(:,70,1,100));
[Svortlen,flen] = pwelch(vorttemp,WL,OL,[],1/dy);

% make vector of NaNs
Svort = NaN(length(Svortlen),length(xpt(1,:)),length(elev),length(Spectime));
fvort = NaN(length(Svortlen),length(xpt(1,:)),length(elev),length(Spectime));

display('Size fvort')
size(fvort)
display('Size Svort')
size(Svort)

for n = 1:length(elev)
    for i = 1:length(xpt(1,:))
        for j = 1:length(Spectime)
            vorttemp = squeeze(vortk_int(:,i,n,Spectime(j)-((dt/2)-1):Spectime(j)+(dt/2)));
            %vorttemp = squeeze(F1.vortk_int(:,i,Spectime(j)-((dt/2)-1):Spectime(j)+(dt/2)),n))
            for k = 1:length(vorttemp(:,1,1))
                % vortra(k,i,n,j) = nanmean(squeeze(vorttemp(k,n,:)));
                vortra(k) = nanmean(squeeze(vorttemp(k,:)));
            end
            % calc spectra for vort
            % checknans = sum(isnan(vortra(:,i,n,j)));
            checknans = sum(isnan(vortra));
            if checknans > 0; % 0.1*length(Spectime);
                %[Svort(:,i,n,j),fvort(:,i,n,j)] = [NaN(length(Svort)),NaN(length(flen))];
                %	display('More NaNs then 10 percent of processed run time')
                %elseif checknans > 0
                %    % temp = find(~isnan(vortra(:,i,n,j)));
                %    temp = find(~isnan(vortra));
                %    	display([num2str(checknans),'~NaNs in vort ',num2str(xp(1,i)),' time ',num2str(Spectime(i))])
                %    % [Svort(:,i,n,j),fvort(:,i,n,j)] = pwelch(vortra(temp,i,n,j),WL,OL,[],1/dy);  %Uses Welch's periodogram method
                %	[Svort(:,i,n,j),fvort(:,i,n,j)] = pwelch(vortra(temp),WL,OL,[],1/dy);  %Uses Welch's periodogram method
            elseif checknans == 0
                % [Svort(:,i,n,j),fvort(:,i,n,j)] = pwelch(vortra(:,i,n,j),WL,OL,[],1/dy);  %Uses Welch's periodogram method
                [Svort(:,i,n,j),fvort(:,i,n,j)] = pwelch(vortra,WL,OL,[],1/dy);  %Uses Welch's periodogram method
            end
        end
        % calc avg spectra over hour
        for m = 1:length(fvort(:,1,1,1))
            Svort_avg(m,i,n) = nanmean(squeeze(Svort(m,i,n,:)));
        end
        display(['cross-shore ',num2str(xp(1,i)),' m'])
        clear vorttemp vortra
    end
    display(['elev ',num2str(elev(n))])
end
f  = squeeze(fvort(:,1,1,1));
sname2 = [savefolder,'alongshore_wavenumber_spectra/sim',simno,'_alongshore_wavenumber_vort_spectra_elev_resx',num2str(resx),'m.mat'];
eval(['save -v7.3 ',sname2,' Svort',' fvort',' Spectime',' dt',' yp',' xp',' h',' dy',' elev'])
clear Svort fvort vortra fvort


%% STEP 5: Save data

% eval(['save -v7.3 ',sname1,' vort',' locx',' Spectime'])
% eval(['save -v7.3 ',sname2,' Svort',' fvort',' locx',' Spectime',' dt',' dy'])
eval(['save -v7.3 ',sname1,' Svort_avg',' f',' Spectime',' dt',' xp',' yp',' h',' dy',' elev'])

display('Done save_offshore_spectra.')

% end
