function calc_alongshore_wavenumber_spectra_vorticity_transects(savefolder,simno,Spectime,xloc,elev,tide,WL,OL,dt)
% This script will save alongshore transects of velocity.
% INPUT:
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% Spectime: time when the alongshore wavenumber spectra will be computer
% xloc: cross-shore location where the spectra is being computed
% elev: elevations that velocity is inpterpolated to
% tide: tidal elevation of simulation
% WL: window length for pwelch
% OL: Overlap length for pwelch
% dt: time step of simulation
% OUTPUT:
% saved in subfolder: alongshore_wavenumber_spectra/
% sim:#_alongshore_transect_vort_',num2str(xloc),'m.mat = z elevations and velocity
% sim:#_alongshore_wavenumber_vort_spectra_',num2str(xloc),'m.mat = spectra
% sim:#_alongshore_wavenumber_vort_spectra_avg_',num2str(xloc),'m.mat = averaged spectra
% 
% %%%%%%%%%%%%%%%%%%%%%%%%% USE IF DEBUGGING %%%%%%%%%%%%%%%%%%%%%%%%
% clc
% clear all
% close all
% addpath(genpath('/data2/baker/SWASH/BATHYDuck15/codes/SWASH_analysis'));
% addpath(genpath('/data2/baker/MTOOLS'));
% frfpath  = '/data2/baker/Observations_BD15/data/';
% % path = '/Users/cmbaker9/Documents/Research/SWASH/BATHYDuck/';
% path  = '/data2/baker/SWASH/BATHYDuck15/';
% 
% 
% % Simulation Details
% dateran= '19_04'; % month of simulation
% date   = '28-Oct-2015 00:00:00'; % date of forcing for simulation
% simno  = '48';    % arbritrary number that helps name simulations related to date
% time   = '7200'; % simulation time
% layers = 5;      % number of layers in simulation
% tide   = -0.320;  % tidal elevation in model run
% tpos   = 3601;   % start time for calculating time-averages parameters
% tend   = 7200;   % end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
% fdomno = 2;      % number of .mat files the full domain is seperated in
% subno  = 3;      % number of .mat files the subgrid is seperated in
% 
% 
% % Consistant simulation folder name (same for run and data)
% simfolder    = ['sim',simno,'_',date(1:2),'-',date(4:6),'-',date(8:11),'_',date(13:14),'00/'];
% % simfolder = 'shore-normal_waves/';
% 
% % Run: simulation output location
% subfolder = 'sim48_nospread/';%'try4_final/';%[time,'_',num2str(layers),'_layers_PSlowvisc/']; 
% runfolder     = [path,'runs/',dateran,'/',simfolder,subfolder,''];
% 
% % Data: processed simulation output location
% ssubfolder = [subfolder,''];%['sim',simno,'_',date(1:2),'-',date(4:6),'-',date(8:11),'_',date(13:14),'00/'];
% %[time,'_',num2str(layers),'_layers/'];
% savefolder = [path,'data/',simfolder,ssubfolder];
% % savefolder = runfolder;
% 
% % Observations: location of processed observations to compare with swash simulations
% frfsubfolder = '';
% frffolder = [frfpath,frfsubfolder];
% 
% WL     = [];
% OL     = [];
% dt     = 60;     % length of time to compute spectra
% Spectime = [(tpos+(dt/2)-1):1:(tend-(dt/2)-1)]-3600;
% elev = flipud([-5:0.1:-0.1]');
% ashore_transects = [150; 174; 200; 226; 250; 300; 400; 500];
% xloc = ashore_transects(1);

%%%%%%%%%%%%%%%%%%%%%%%%% USE ABOVE FOR DEBUGGING %%%%%%%%%%%%%%%%%%%%%%%%

display('Start alongshore wavenumber spectra.')

%% STEP 1: Load data
load([savefolder,'sim',simno,'_subgrid_domain.mat']);
ypsub = yp;
xpsub = xp;
hsub  = h;
clear xp yp h beach
load([savefolder,'sim',simno,'_domain.mat']);
load([savefolder,'sim',simno,'_Hs.mat']);
dy = yp(2,1)-yp(1,1);  % dy in simulation, this is 2 m
F1 = matfile([savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_alongshore_transects_x',num2str(xloc-dy),'to',num2str(xloc+dy),'m.mat']); % vel,vort,wlev,z,x,y
dl = length(F1.vel_uk_int(1,:,1,1));
vel_u = squeeze(F1.vel_uk_int(:,((dl-1)/2)+1,:,:));
vel_v = squeeze(F1.vel_vk_int(:,((dl-1)/2)+1,:,:));
vort  = squeeze(F1.vortk(:,((dl-1)/2)+1,:,:));
xpt   = F1.xpt;
elev  = F1.elev;

%% STEP 2: Save name

sname1 = [savefolder,'alongshore_wavenumber_spectra/sim',simno,'_alongshore_transect_vort_',num2str(xloc),'m.mat'];
sname2 = [savefolder,'alongshore_wavenumber_spectra/sim',simno,'_alongshore_wavenumber_vort_spectra_',num2str(xloc),'m.mat'];
sname3 = [savefolder,'alongshore_wavenumber_spectra/sim',simno,'_alongshore_wavenumber_vort_spectra_avg_',num2str(xloc),'m.mat'];

%% STEP 3: Fix domain and pick location 

xfrf = fliplr(900-xp)+50;
yfrf = -244+yp;
x = length(xp(1,:)); % size x-dimension
y = length(yp(1,:)); % size x-dimension
xsub = length(xpsub(1,:));
ysub = length(ypsub(:,1)); % size y-dimension

for i = 1:xsub
    xisub(i) = find(xpsub(1,i) == xp(1,:));
end

for i = 1:ysub
    yisub(i) = find(ypsub(i,1) == yp(:,1));
end

range               = 1;

x_loc_frf           = find(xfrf(1,:)==xloc); % find the grid location of the cross-shore specified locations
x_loc_check_frf     = xfrf(1,x_loc_frf) % this is a check to make sure you are saving the right location is chosen in the frf domain
xsim                = x-(x_loc_frf-1);  % find the grid location in the simulation format
xi                  = [xsim-range:xsim+range]; % pick locations around this for vorticity
x_loc_check_sim     = (900-xp(1,xi)+50) % this is another test to check if the right location is chosen in the simulation domain

% % Check to make sure above is correct output
% test        = squeeze(F1.vel_u(:,:,2,3600));
% fliptest    = fliplr(test);
% velsim      = test(:,xi);
% velfrf      = fliptest(:,x_loc_frf-1:x_loc_frf+1);
% dif         = fliplr(velsim)-velfrf
xpt     = xfrf(:,x_loc_frf-range:x_loc_frf+range);

% x_actual = length(x(1,:)); % find the length of x simulation
% % x_loc = (length(x(1,:))+1)-x_actual;
% for i = 1:length(xloc)
%     x_loc_frf       = find(x(1,:)==xloc(i)); % find the grid location of the cross-shore specified locations
%      x_loc_check_frf(i)        = x(1,x_loc_frf); % this is a check to make sure you are saving the right location is chosen in the frf domain
%     x_loc_check_sim(i)        = xp(1,x_actual-x_loc_frf); % this is another test to check if the right location is chosen in the simulation domain
%     x_loc_sim(i)    = x_actual-x_loc_frf;  % find the grid location in the simulation format
% end
% x_loc_sim
% x_loc_check_frf
% x_loc_check_sim

%% STEP : Find location

% for i = 1:length(xpt(1,:))
%     Lx = find(xp(1,:)==xloc);
%     Ly(i) = find(yp(:,1)==xpt(1,:));
% end

%% STEP 5: Change any zero value to NaN
% Note that once this is fixed in my main code for interpolating, then
% these lines can be removed.

for i = 1:ysub
    for j = 1:length(elev)
        for k = 1:length(vort(1,1,:)) % length(tpos-tend)
%             if vel_u(i,j,k) == 0
%                 vel_u(i,j,k) = NaN;
%             end
%             if vel_v(i,j,k) == 0
%                 vel_v(i,j,k) = NaN;
%             end
            if vort(i,j,k) == 0
                vort(i,j,k) = NaN;
            end
            % if vel_u(k,l) == 0
            %     vel_u(k,l) = NaN;
            % end
            % if vel_v(k,l) == 0
            %     vel_v(k,l) = NaN;
            % end
        end
    end
end

%% STEP: Find Lz

Hsig = squeeze(Hs_4std(yisub,xisub));

% Specificy top elevation (near-surface)
for i = 1:ysub
    Hspt(i) = Hs_4std(yisub(i),xsim);
%     Lz1(i) = mustBePositive(-elev)-Hspt/2;
    A = repmat(Hspt(i)/2,length(elev),1); % make matrix of repeating y_mean values
    [minValue,close_i]  = nanmin(abs((-elev)-A)); % find the location of the minimum dif between the y_mean and the alongshore coordinates
    % make a 4x1 matrix of the indicies of the alongshore coordinates, centered
    % around y_mean
    if Hspt(i)/2 < -elev(close_i,1)
        z1(i) = elev(close_i,1);
    elseif Hspt(i)/2 > -elev(close_i,1)
        z1(i) = elev(close_i+1,1);
    end
    % check that this is done right
    Hspt(i)/2;
    z1(i);
end

% Specicy bottom elevation
for i = 1:ysub
    hpt(i) = h(yisub(i),xsim);
%     Lz1(i) = mustBePositive(-elev)-Hspt/2;
    A = repmat(hpt(i),length(elev),1); % make matrix of repeating y_mean values
    [minValue,close_i]  = nanmin(abs((-elev)-A)); % find the location of the minimum dif between the y_mean and the alongshore coordinates
    % make a 4x1 matrix of the indicies of the alongshore coordinates, centered
    % around y_mean
    if hpt(i) > -elev(close_i,1)
        z3(i) = elev(close_i-2,1);
    elseif hpt(i) <= -elev(close_i,1)
        z3(i) = elev(close_i-3,1);       
    end
%     if z3(i) = 0
%         z3(i) = 
%     Lz2(i) = elev(round(close_i/2),1);
    % check that this is done right
%     hpt(i)
%     Lz3(i)
end
z2 = round((z1+(z3-z1)/2),1);
check_z3 = (-z3)-hpt;
check_z2 = z2-z3/2;
for i = 1:length(z1)
    Lz1(i) = find(z1(1,i)==elev);
    Lz2(i) = find(round(z2(1,i),1)==round(elev,1));
    Lz3(i) = find(round(z3(1,i),1)==round(elev,1));
end

%% STEP 4: Calculate Modeled Spectra

for i = 1:3
    for j = 1:length(Spectime)
        eval(['vorttemp = vort(:,Lz',num2str(i),',Spectime(j)-((dt/2)-1):Spectime(j)+(dt/2));'])
        %vtemp = squeeze(Fvel.vel_v(:,x_loc_sim(i),Spectime(j)-4:Spectime(j)+4));
        for k = 1:length(vorttemp(:,1,1))
            vort(k,i,j) = nanmean(squeeze(vorttemp(k,:)));
            %v(k,i,j) = nanmean(squeeze(vtemp(k,:)));
        end
        % calc spectra for vort
        checknans = sum(isnan(vort(:,i,j)));
        if checknans > 0
            temp = find(~isnan(vort(:,i,j)));
            display([num2str(checknans),'~NaNs in vort ',num2str(xloc),' time ',num2str(Spectime(i))])
            [Svort(:,i,j),fvort(:,i,j),Svortc95(:,:,i,j)] = pwelch(vort(temp,i,j),WL,OL,[],1/dy);  %Uses Welch's periodogram method
        else
            [Svort(:,i,j),fvort(:,i,j),Svortc95(:,:,i,j)] = pwelch(vort(:,i,j),WL,OL,[],1/dy);  %Uses Welch's periodogram method
        end
    end

% calc avg spectra over hour
for m = 1:length(fvort(:,1,1))
    Svort_avg(m,i) = nanmean(squeeze(Svort(m,i,:)));
    for co = 1:2
        Svortc95_avg(m,co,i) = nanmean(squeeze(Svortc95(m,co,i,:)));
    end
end
display(['cross-shore ',num2str(xloc),' m'])
end
    
f  = squeeze(fvort(:,1,1));

% for i = 1:length(xloc) 
%     vort(:,i,:) = squeeze(Fvel.vort(:,x_loc_sim(i),Spectime));%tpos:tend));
% %    v(:,i,:) = squeeze(Fvel.vel_v(:,x_loc_sim(i),Spectime));%tpos:tend));
% end

% process vort
% for i = 1:length(xloc)
%     for j = 1:length(Spectime)
%         checknans = sum(isnan(vort(:,i,j)));
%         if checknans > 0
%             temp = find(~isnan(vort(:,i,j)));
%             display([num2str(checknans),'~NaNs in vort ',num2str(xloc(i)),' time ',num2str(Spectime(i))])
%             [Svort(:,i,j),f(:,i,j)] = pwelch(vort(temp,i,j),WL,OL,128,1/dy);  %Uses Welch's periodogram method
%         else
%             [Svort(:,i,j),f(:,i,j)] = pwelch(vort(:,i,j),WL,OL,128,1/dy);  %Uses Welch's periodogram method
%         end
%     end
% end



%% STEP 5: Save data

eval(['save -v7.3 ',sname1,' vort',' xloc',' Spectime',' Lz1',' Lz2',' Lz3',' elev'])
eval(['save -v7.3 ',sname2,' Svort',' Svortc95',' fvort',' xloc',' Spectime',' dt',' dy',' Lz1',' Lz2',' Lz3',' elev'])
eval(['save -v7.3 ',sname3,' Svort_avg',' Svortc95_avg',' f',' xloc',' Spectime',' dt',' dy',' Lz1',' Lz2',' Lz3',' elev'])

display('Done save_offshore_spectra.')

% end
