function calc_coherence_phase_spectra_rotary_crossshore_005_meanremoved(savefolder,simno,num_in_squ,xshore,WL,OL,Tp,BD,Fboundspec,Fboundlp)
% This function will create plots of coherence and phase.
% Coherence: two wave sources are perfectly coherent if they have a constant phase difference and the same frequency, and the same waveform.
%            if coherence = 1, the signals are perfectly correlated or linearly related, and
%            if coherence = 0, they are totally uncorrelated.
% Phase:  Zero phase indicates surface intensifi-cation
%         180deg phase indicates bottom-intensification
%         positive quadrature indicates lag of near-bed velocity (Henderson
%         et al. 2017)
% INPUT:
% savefolder = location where processed data will be saved
% simno      = number of simulation that represents forcing
% tpos       = start time for calculating time-averages parameters
% tend       = end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
% xloc       = x domain location
% yloc       = y domain location
% OUTPUT: 

% Fbounds = [0.004 0.006];

% INPUT:
% datafolder: location on personal computer were data is stored
% figurefolder: location where figure will be stored
% frffolder: location where frf data is stored
% simno: simulation number
% cross_shore_array: specifies which cross-shore transect plotting
% c_axis: colormap axis for both plots of velocity centered on zero
% OUTPUT:
% Cross-shore transect (PDF) ending in crossshore_transect_p##, e.g.:
% sim7_19-Oct-2015_1800___________.pdf% Cross-Spectra: Rotary Spectra

%%%%%%%%%%%%%%%%%%%%

if BD == 1
    F1 = matfile([savefolder,'elevation_interpolations/sim',num2str(simno),'_vel_vort_crossshore_transects_p',num2str(xshore),'.mat']);
elseif BD == 0
    F1 = matfile([savefolder,'elevation_interpolations/sim',num2str(simno),'_vel_vort_crossshore_transects_y',num2str(xshore-2),'to',num2str(xshore+2),'m.mat']);
end

load([savefolder,'sim',simno,'_subgrid_domain.mat']);
load([savefolder,'sim',simno,'_subgrid_Hs.mat']);

if BD == 1
    sname1 = [savefolder,'rotary_spec/sim',simno,'_rotaryspectra_coh_pha_p',num2str(xshore),'_nomean.mat'];
    sname2 = [savefolder,'rotary_spec/sim',simno,'_spectra_coh_pha_p',num2str(xshore),'_nomean.mat'];
    sname3 = [savefolder,'rotary_spec/sim',simno,'_VLF_spectra_and_rotary_p',num2str(xshore),'_VLF005_nomean.mat'];
elseif BD == 0
    sname1 = [savefolder,'rotary_spec/sim',simno,'_rotaryspectra_coh_pha_y',num2str(xshore),'_nomean.mat'];
    sname2 = [savefolder,'rotary_spec/sim',simno,'_spectra_coh_pha_y',num2str(xshore),'_nomean.mat'];
    sname3 = [savefolder,'rotary_spec/sim',simno,'_VLF_spectra_and_rotary_y',num2str(xshore),'_VLF005_nomean.mat'];
    sname4 = [savefolder,'rotary_spec/sim',simno,'_VLF_vlfmag_y',num2str(xshore),'.mat'];
end
tic

display('Start calc coherence and phase with rotary spectra.')
%% STEP 4: Dimensions
% File details
x = length(xp(1,:)); % size x-dimension
y = length(yp(:,1)); % size y-dimension
xp = fliplr(900-xp)+50;
yp = -244+yp;
Hs = fliplr(Hs_4std);
% Hs = Hs_4std;
h   = fliplr(h);
dt = 1;

%% STEP 3: Define time which velocity will be calculated for

vel_u   = squeeze(F1.vel_uk_int(num_in_squ,:,:,:));
vel_v   = squeeze(F1.vel_vk_int(num_in_squ,:,:,:));
vort   = squeeze(F1.vortk(num_in_squ,:,:,:));
for i = 1:length(vel_u(1,1,:))
        vel_u(:,:,i) = -flipud(squeeze(vel_u(:,:,i)));
        vel_v(:,:,i) = flipud(squeeze(vel_v(:,:,i)));
        vort(:,:,i)  = -flipud(squeeze(vort(:,:,i)));
end
    
elev    = F1.elev;
ypt     = F1.ypt(num_in_squ,1);
% y_mean  = F1.y_mean;


%% STEP : Find location

Lx = 1:x;
Ly = find(yp(:,1)==ypt);
Hsloc = Hs(Ly,Lx);
hloc  = h(Ly,Lx);
for i = 1:length(Lx)
    if Hsloc(i) < hloc(i)-.06
        calchere(i) = 1;
    elseif Hsloc(i) > hloc(i)-0.06
        calchere(i) = 0;
    else
        calchere(i) = 0;
    end
end

%% STEP 5: Change any zero value to NaN
% Note that once this is fixed in my main code for interpolating, then
% these lines can be removed.

for i = 1:length(Lx)
    for j = 1:length(elev)
        for k = 1:length(vel_u(1,1,:)) % length(tpos-tend)
            if vel_u(i,j,k) == 0
                vel_u(i,j,k) = NaN;
            end
            if vel_v(i,j,k) == 0
                vel_v(i,j,k) = NaN;
            end
            if vort(i,j,k) == 0
                vort(i,j,k) = NaN;
            end
        end
    end
end

%% STEP 3: Get complex velocities
vel_w     = vel_u+sqrt(-1)*vel_v;

%% STEP: Find the top elevation 

% Specificy top elevation (near-surface)
for i = 1:length(Lx)
    if calchere(i)==1
        Hspt(i) = Hs(Ly,Lx(i));
        %     Lz1(i) = mustBePositive(-elev)-Hspt/2;
        A = repmat(Hspt(i)/2,length(elev),1); % make matrix of repeating y_mean values
        [minValue,close_i]  = nanmin(abs((-elev)-A)); % find the location of the minimum dif between the y_mean and the alongshore coordinates
        % make a 4x1 matrix of the indicies of the alongshore coordinates, centered
        % around y_mean
        if Hspt(i)/2 < -elev(close_i,1)
            z1(i) = elev(close_i,1);
        elseif Hspt(i)/2 >= -elev(close_i,1)
            z1(i) = elev(close_i+1,1);
        end
        % check that this is done right
        Hspt(i)/2;
        z1(i);
        hloc(i);
        
        % Specicy bottom elevation
        hpt(i) = h(Ly,Lx(i));
        %     Lz1(i) = mustBePositive(-elev)-Hspt/2;
        A = repmat(hpt(i),length(elev),1); % make matrix of repeating y_mean values
        [minValue,close_i]  = nanmin(abs((-elev)-A)); % find the location of the minimum dif between the y_mean and the alongshore coordinates
        % make a 4x1 matrix of the indicies of the alongshore coordinates, centered
        % around y_mean
        if hpt(i) > -elev(close_i,1)
            z3(i)   = elev(close_i-3,1);
            bot(i) = elev(close_i,1);
        elseif hpt(i) <= -elev(close_i,1)
            z3(i) = elev(close_i-4,1);
            bot(i) = elev(close_i-1,1);
        end
        z2(i) = round((z1(i)+(z3(i)-z1(i))/2),1);
%         check_z3 = (-z3)-hpt
%         check_z2 = z2-z3/2
        Lz1(i) = find(z1(i)==elev);
        Lz2(i) = find(z2(i)==round(elev,1));
        Lz3(i) = find(z3(i)==elev);
        Lzbot(i) = find(bot(i)==elev);
    elseif calchere(i) == 0
        z3(i) = NaN;
        z2(i) = NaN;
        z1(i) = NaN;
        Lzbot(i) = NaN;
        Lz3(i) = NaN;
        Lz2(i) = NaN;
        Lz1(i) = NaN;
        Lzbot(i) = NaN;
    end
end

%% STEP 2: Create Empty Variables

for i = 1;
% get length that NaNs should be multiplied by
utemp               = squeeze(vel_u(100,10,:));
vtemp               = squeeze(vel_v(100,10,:));
wtemp               = squeeze(vel_w(100,10,:));
[Cutemp,Futemp,Cuctemp] = cpsd(utemp,utemp,hanning(512),256,[],dt,'confidencelevel',0.95);
[Cwtemp,Fwtemp,Cwctemp] = cpsd(wtemp,wtemp,hanning(512),256,[],dt,'confidencelevel',0.95);
F2temp              = Fwtemp(1:round(length(Fwtemp)/2));
% nan matrices 
nan2d               = repmat(NaN,x,length(elev));
nan3d               = repmat(NaN,x,length(elev),length(Futemp));
nan4d               = repmat(NaN,x,length(elev),length(Futemp),2);
nan3dro             = repmat(NaN,x,length(elev),length(F2temp));
nan4dro             = repmat(NaN,x,length(elev),length(F2temp),2);

% Make matrix with all NaNs              
% SPECTRA
Cuu                 = nan3d;    % Cuu    = auto-spectra cross-shore velocity
Cuuc                = nan4d;    % Cuuc   = 95% confidence interval of auto-spectra cross-shore velocity
Cvv                 = nan3d;    % Cvv    = auto-spectra alongshore velocity
Cvvc                = nan4d;    % Cvvc   = 95% confidence interval of auto-spectra alongshore velocity
Fu                  = nan3d;    % Fu     = frequency for cross-shore spectra   
Fv                  = nan3d;    % Fv     = frequency for alonghore spectra
Cux                 = nan3d;    % Cux    = cross-spectra from 2 elevations of cross-shore velocity
Cvx                 = nan3d;    % Cvx    = cross-spectra from 2 elevations of alongshore velocity    
Cuxc                = nan4d;    % Cuxc   = 95% confidence interval of cross-spectra from 2 elevations of cross-shore velocity
Cvxc                = nan4d;    % Cvxc   = 95% confidence interval of cross-spectra from 2 elevations of alongshore velocity
VLF.Specuu          = nan2d;    % Specuu        = cross-shore velocity rotary spectra in VLFs
VLF.Specvv          = nan2d;    % Specvv        = alongshore velocity rotary spectra in VLFs
% root mean square velocity relative to uppermost location (u/u0)rms
uvlf                = repmat(NaN,x,length(elev),length(utemp));
% uvlf                = repmat(NaN,x,length(elev),length(utemp));
up                  = repmat(NaN,x,length(elev),length(utemp));
ustd                = nan2d;    % standard deviation of cross-shore velocity at location
vstd                = nan2d;    % standard deviation of alongshore velocity at location
VLF.ustd            = nan2d;
VLF.vstd            = nan2d;
uurms               = nan2d;    % root-mean-square of cross-shore velocity relative to uppermost sensor
vvrms               = nan2d;    % root-mean-square of alongshore velocity relative to uppermost sensor
VLF.urms            = nan2d;
VLF.vrms            = nan2d;
VLF.uurms           = nan2d;
VLF.vvrms           = nan2d;
% Coherence
cohu                = nan3d;    % cohu   = coherence of cross-shore auto-spectras
cohv                = nan3d;    % cohv   = coherence of alongshore auto-spectras
% Phase
phau                = nan3d;    % phau   = phase of cross-shore auto-spectras
phav                = nan3d;    % phav   = phase of alongshore auto-spectras
% VLF coherence and phase
VLF.cohu            = nan2d;    % coherence_u   = cross-shore coherence in VLFs
VLF.cohv            = nan2d;    % coherence_v   = alongshore velocity spectra coherence in VLFs
VLF.phau            = nan2d;    % phase_u       = cross-shore velocity spectra phase in VLFs
VLF.phav            = nan2d;    % phase_v       = alongshore velocity spectra phase in VLFs

% ROTARY SPECTRA
Cpp                 = nan3dro;  % Cpp    = positive (cw?) rotary auto-spectra
Cppc                = nan4dro;  % Cppc   = 95% confidence interval of positive rotary auto-spectra
Cnn                 = nan3dro;  % Cnn    = negative (ccw?) rotary auto-spectra
Cnnc                = nan4dro;  % Cnnc   = 95% confidence interval of negative rotary auto-spectra
Fw                  = nan3dro;  % Fw     = frequency for rotary spectras
Cppx                = nan3dro;  % Cppx   = positive cross-spectra from 2 elevations
Cppxc               = nan4dro;  % Cppxc  = 95% confidence interval of positive rotary cross-spectra at 2 elevations
Cnnx                = nan3dro;  % Cnnx   = negative cross-spectra from 2 elevations
Cnnxc               = nan4dro;  % Cnnxc  = 95% confidence interval of negative rotary cross-spectra at 2 elevations
VLF.Specnn          = nan2d;    % Specpp        = average positive rotary spectra in VLFs
VLF.Specpp          = nan2d;    % Specnn        = average negative rotary spectra in VLFs
% rotary ratio
Rpn                 = nan3dro;  % Rpn    = ratio of positive and negative rotary spectras at all frequencies
VLF.Rpn             = nan2d;    % Rpn      = rotary spectra coefficient
% % mean oritentation
% roang               = nan3dro;  % roang = mean orientation
% VLF.roang           = nan2d;    % mean orientation in VLF
% rotary coherence
rocohp              = nan3dro;  % rochop = coherence of postivie rotary spectras
rocohn              = nan3dro;  % rochon = coherence of negative rotary spectras
Frocoh              = nan3dro;  % Frocoh = frequency for coherence
% rotary phase
rophap              = nan3dro;  % rophap = phase of postive rotary spectras
rophan              = nan3dro;  % rophan = phase of negative rotaroy spectras
Fropha              = nan3dro;  % Fropha = frequency phase of rotary spectras
% VLF rotary coherence and phase
VLF.rocohp          = nan2d;    % rocoherence_p = positive rotary spectra coherence in VLFs
VLF.rocohn          = nan2d;    % rocoherence_n = negative rotary spectra coherence in VLFs
VLF.rophap          = nan2d;    % rophase_p     = postive rotary spectra phase in VLFs
VLF.rophan          = nan2d;    % rophase_n     = negative rotary spectra phase in VLFs
clear *temp
end

for i = 1:length(Lx)
   if calchere == 0
        continue
   elseif calchere(i) == 1
        % Find velocity at top elevation
        u1 = squeeze(vel_u(Lx(i),Lz1(i),:));
        v1 = squeeze(vel_v(Lx(i),Lz1(i),:));
        w1 = squeeze(vel_w(Lx(i),Lz1(i),:));
        testa1     = find(isnan(u1));
        u1(testa1) = [];
        testa2     = find(isnan(v1));
        v1(testa2) = [];
        testa3     = find(isnan(w1));
        w1(testa3) = [];
        clear test*
        if sum(~isnan(u1))>0       
            % Calc spectra at top level
            [Cuu1,Fu1,Cuc1] = cpsd(u1-nanmean(u1),u1-nanmean(u1),hanning(512),256,[],1/dt,'confidencelevel',0.95);
            [Cvv1,Fv1,Cvc1] = cpsd(v1-nanmean(v1),v1-nanmean(v1),hanning(512),256,[],1/dt,'confidencelevel',0.95);
            % Calculate Rotary Spectra
            [Cww1,Fw1,Cwc1] = cpsd(w1-nanmean(w1),w1-nanmean(w1),hanning(512),256,[],1/dt,'confidencelevel',0.95);
            % positive here is cw
            % negative here is ccw
            Cpp1            = Cww1(1:length(Fw1)/2);
            Cppc1           = Cwc1(1:length(Fw1)/2,:);
            Cnn1            = flipud(Cww1(length(Fw1)/2+1:end));
            Cnnc1           = flipud(Cwc1(length(Fw1)/2+1:end,:));
            Fw1             = Fw1(1:length(Fw1)/2);
            % rms velocity
            u1vlf               = pl64ta(u1,1/Fboundlp(2))-pl64ta(u1,1/Fboundlp(1));
            v1vlf               = pl64ta(v1,1/Fboundlp(2))-pl64ta(v1,1/Fboundlp(1));
        end
        for j = 1:length(elev)
            if elev(j) == z1(i) % if the elevation at the top location to calc
                elevtb(i,1) = elev(j);
                % SPECTRA
                Cuu(i,j,:)          = Cuu1;
                Cuuc(i,j,:,:)       = Cuc1;
                Cvv(i,j,:)          = Cvv1;
                Cvvc(i,j,:,:)       = Cvc1;
                Fu(i,j,:)           = Fu1;
                Fv(i,j,:)           = Fv1;
                % rms velocity
                uvlf(i,j,:)         = u1vlf;
                vvlf(i,j,:)         = v1vlf;
                % std dev
                VLF.ustd(i,j)       = nanstd(u1vlf);
                VLF.vstd(i,j)       = nanstd(v1vlf);
                % spectra VLF avg
                % Fbound(1) < f < Fbound(2)
                F                   = Fu1;
                A                   = repmat(Fboundspec(1),length(F),1);
                B                   = repmat(Fboundspec(2),length(F),1);
                [minValueA,closeA]  = nanmin(abs((F)-A));
                [minValueB,closeB]  = nanmin(abs((F)-B));
                F_AB                = squeeze(F(closeA:closeB));
                Cuu_AB              = squeeze(Cuu(i,j,closeA:closeB));
                Cvv_AB              = squeeze(Cvv(i,j,closeA:closeB));
                VLF.Fuv             = F_AB;
                VLF.Specuu(i,j)     = nansum(Cuu_AB); %trapz(F_AB,Cuu_AB)/(F_AB(end)-F_AB(1));
                VLF.Specvv(i,j)     = nansum(Cvv_AB); %trapz(F_AB,Cvv_AB)/(F_AB(end)-F_AB(1));
                VLF.urms(i,j)       = rms(u1vlf);
                VLF.vrms(i,j)       = rms(v1vlf);
                clear *_AB F minValue* close*       
                
                % ROTARY SPECTRA
                Cpp(i,j,:)          = Cpp1;
                Cppc(i,j,:,:)       = Cppc1;
                Cnn(i,j,:)          = Cnn1;
                Cnnc(i,j,:,:)       = Cnnc1;
                Fw(i,j,:)           = Fw1;
                % Rotary Ratio
                Rpn(i,j,:)          = (Cpp1-Cnn1)./(Cpp1+Cnn1);
                % mean orientation
                [Cuv1,Fu1,Cuvc1]    = cpsd(u1-nanmean(u1),v1-nanmean(v1),hanning(512),256,[],1/dt,'confidencelevel',0.95);
                roang(i,j,:)        = (atan(2*(Cuv1)./(Cuu1-Cvv1)))/2;
                % spectra VLF avg
                % Fboundspec(1) < f < Fboundspec(2)
                A                   = repmat(Fboundspec(1),length(Fw1),1);
                B                   = repmat(Fboundspec(2),length(Fw1),1);
                [minValueA,closeA]  = nanmin(abs((Fw1)-A));
                [minValueB,closeB]  = nanmin(abs((Fw1)-B));
                F_AB                = squeeze(Fw(i,j,closeA:closeB));
                Cpp_AB              = squeeze(Cpp(i,j,closeA:closeB));
                Cnn_AB              = squeeze(Cnn(i,j,closeA:closeB));
                Rpn_AB              = squeeze(Rpn(i,j,closeA:closeB));
                roang_AB            = squeeze(roang(i,j,closeA:closeB));
                VLF.Fww             = F_AB;
                VLF.Specpp(i,j)     = nansum(Cpp_AB); %trapz(F_AB,Cpp_AB)/(F_AB(end)-F_AB(1));
                VLF.Specnn(i,j)     = nansum(Cnn_AB); %trapz(F_AB,Cnn_AB)/(F_AB(end)-F_AB(1));
                VLF.Rpn(i,j)        = trapz(F_AB,Rpn_AB)/(F_AB(end)-F_AB(1));
                VLF.roang(i,j)      = trapz(F_AB,roang_AB)/(F_AB(end)-F_AB(1));
                
                clear *_AB F minValue* close*
                
            elseif elev(j) < z1(i) && elev(j) >= z3(i)
                u2 = squeeze(vel_u(Lx(i),j,:));
                v2 = squeeze(vel_v(Lx(i),j,:));
                w2 = squeeze(vel_w(Lx(i),j,:));
                testb1     = find(isnan(u2));
                u2(testb1) = [];
%                 u2(testa1) = [];
%                 u1(testb1) = [];
%                 u1(testa1) = []
                test     = find(isnan(v2));
                v2(test) = [];
                test     = find(isnan(w2));
                w2(test) = [];
                if sum(~isnan(u2))==0
                    continue
                end
                clear test
                
                % SPECTRA
                % Calc auto- and cross-spectra
                [Cuu2,Fu2,Cuc2]     = cpsd(u2-nanmean(u2),u2-nanmean(u2),hanning(512),256,[],1/dt,'confidencelevel',0.95);
                [Cvv2,Fv2,Cvc2]     = cpsd(v2-nanmean(v2),v2-nanmean(v2),hanning(512),256,[],1/dt,'confidencelevel',0.95);
                [Cuu12,Fu12,Cuc12]  = cpsd(u1-nanmean(u1),u2-nanmean(u2),hanning(512),256,[],1/dt,'confidencelevel',0.95);
                [Cvv12,Fv12,Cvc12]  = cpsd(v1-nanmean(v1),v2-nanmean(v2),hanning(512),256,[],1/dt,'confidencelevel',0.95);
                % store spectra
                Cuu(i,j,:)          = Cuu2;
                Cuuc(i,j,:,:)       = Cuc2;
                Cvv(i,j,:)          = Cvv2;
                Cvvc(i,j,:,:)       = Cvc2;
                Fu(i,j,:)           = Fu2;
                Fv(i,j,:)           = Fv2;
                Cux(i,j,:,:)        = Cuu12;
                Cvx(i,j,:,:)        = Cvv12;
                Cuxc(i,j,:,:)       = Cuc12;
                Cvxc(i,j,:,:)       = Cvc12;
                % rms velocity
                u2vlf               = pl64ta(u2,1/Fboundlp(2))-pl64ta(u2,1/Fboundlp(1));
                uvlf(i,j,:)         = u2vlf;
                v2vlf               = pl64ta(v2,1/Fboundlp(2))-pl64ta(v2,1/Fboundlp(1));
                vvlf(i,j,:)         = v2vlf;
                VLF.urms(i,j)       = rms(u2vlf);
                VLF.vrms(i,j)       = rms(v2vlf);
                VLF.uurms(i,j)      = rms(u2vlf)/rms(u1vlf);
                VLF.vvrms(i,j)      = rms(v2vlf)/rms(v1vlf);
                % std dev
                VLF.ustd(i,j)       = nanstd(u2vlf);
                VLF.vstd(i,j)       = nanstd(v2vlf);
                % Coherence
                cohu(i,j,:)         = (abs(Cuu12).^2)./(Cuu1.*Cuu2);
                cohv(i,j,:)         = (abs(Cvv12).^2)./(Cvv1.*Cvv2);
                % Phase
                phau(i,j,:)         = angle(Cuu12)*(180/pi);
                phav(i,j,:)         = angle(Cvv12)*(180/pi);
                % spectra VLF avg
                % Fboundspec(1) < f < Fboundspec(2)
                F                   = Fu2;
                A                   = repmat(Fboundspec(1),length(F),1);
                B                   = repmat(Fboundspec(2),length(F),1);
                [minValueA,closeA]  = nanmin(abs((F)-A));
                [minValueB,closeB]  = nanmin(abs((F)-B));
                F_AB                = squeeze(F(closeA:closeB));
                Cuu_AB              = squeeze(Cuu(i,j,closeA:closeB));
                Cvv_AB              = squeeze(Cvv(i,j,closeA:closeB));
                cohu_AB             = squeeze(cohu(i,j,closeA:closeB));
                cohv_AB             = squeeze(cohv(i,j,closeA:closeB));
                phau_AB             = squeeze(phau(i,j,closeA:closeB));
                phav_AB             = squeeze(phav(i,j,closeA:closeB));
                
                VLF.Specuu(i,j)     = nansum(Cuu_AB); %trapz(F_AB,Cuu_AB)/(F_AB(end)-F_AB(1));
                VLF.Specvv(i,j)     = nansum(Cvv_AB); %trapz(F_AB,Cvv_AB)/(F_AB(end)-F_AB(1));
                VLF.cohu(i,j)       = trapz(F_AB,cohu_AB)/(F_AB(end)-F_AB(1));
                VLF.cohv(i,j)       = trapz(F_AB,cohv_AB)/(F_AB(end)-F_AB(1));
                VLF.phau(i,j)       = trapz(F_AB,phau_AB)/(F_AB(end)-F_AB(1));
                VLF.phav(i,j)       = trapz(F_AB,phav_AB)/(F_AB(end)-F_AB(1));
                clear *_AB F minValue* close*
                
                % ROTARY SPECTRA
                
                % Calculate Rotary Spectra using pwelch
                [Cww2,Fw2,Cwc2]     = cpsd(w2-nanmean(w2),w2-nanmean(w2),hanning(512),256,[],1/dt,'confidencelevel',0.95);
                [Cww12,Fw12,Cwc12]  = cpsd(w1-nanmean(w1),w2-nanmean(w2),hanning(512),256,[],1/dt,'confidencelevel',0.95);
                Cpp2                = Cww2(1:length(Fw2)/2);
                Cppc2               = Cwc2(1:length(Fw2)/2,:);
                Cnn2                = flipud(Cww2(length(Fw2)/2+1:end));
                Cnnc2               = flipud(Cwc2(length(Fw2)/2+1:end,:));
                Fw2                 = Fw2(1:length(Fw2)/2);
                Cppx                = Cww12(1:length(Fw2)/2);
                Cppxc               = Cwc12(1:length(Fw2)/2,:);
                Cnnx                = flipud(Cww12(length(Fw2)/2+1:end));
                Cnnxc               = flipud(Cwc12(length(Fw2)/2+1:end,:));
                % store rotary spectra
                Cpp(i,j,:)          = Cpp2;
                Cppc(i,j,:,:)       = Cppc2;
                Cnn(i,j,:)          = Cnn2;
                Cnnc(i,j,:,:)       = Cnnc2;
                Fw(i,j,:)           = Fw2;  
                % Rotary Ratio
                Rpn(i,j,:)          = (Cpp2-Cnn2)./(Cpp2+Cnn2);
                % Mean Orientation
                [Cuv2,Fu2,Cuvc2]    = cpsd(u2-nanmean(u2),v2-nanmean(v2),hanning(512),256,[],1/dt,'confidencelevel',0.95);
                roang(i,j,:)        = 0.5*atan2(2*abs(Cuv2),(Cuu2-Cvv2))*180/pi;%(atan(2*(Cuv2)./(Cuu1-Cvv2)))/2;
                % Coherence
%                 [rocoh,F]           = mscohere(w1,w2,hanning(512),256,[],1);
                rocoh               = (abs(Cww12).^2)./(Cww1.*Cww2);
                rocohp(i,j,:)       = rocoh(1:length(Fw12)/2);
                rocohn(i,j,:)       = flipud(rocoh(length(Fw12)/2+1:end));
%                 Frocoh(i,j,:)         = F(1:length(F)/2);
                % Get Rotary Phase
                ropha               = (180/pi)*angle(Cww12);
                rophap(i,j,:)       = ropha(1:length(Fw12)/2);
                rophan(i,j,:)       = flipud(ropha(length(Fw12)/2+1:end));
                Fropha(i,j,:)       = Fw12(1:length(Fw12)/2);
                % VLF avg
                % rotaroy spectra VLF avg
                % Fboundspec(1) < f < Fboundspec(2)
                F                   = Fw2;
                A                   = repmat(Fboundspec(1),length(F),1);
                B                   = repmat(Fboundspec(2),length(F),1);
                [minValueA,closeA]  = nanmin(abs((F)-A));
                [minValueB,closeB]  = nanmin(abs((F)-B));
                F_AB                = squeeze(F(closeA:closeB));
                Cpp_AB              = squeeze(Cpp(i,j,closeA:closeB));
                Cnn_AB              = squeeze(Cnn(i,j,closeA:closeB));
                Rpn_AB              = squeeze(Rpn(i,j,closeA:closeB));
                roang_AB            = squeeze(roang(i,j,closeA:closeB));
                rocohp_AB           = squeeze(rocohp(i,j,closeA:closeB));
                rocohn_AB           = squeeze(rocohn(i,j,closeA:closeB));
                rophap_AB           = squeeze(rophap(i,j,closeA:closeB));
                rophan_AB           = squeeze(rophan(i,j,closeA:closeB));
                VLF.Specpp(i,j)     = nansum(Cpp_AB); %trapz(F_AB,Cpp_AB)/(F_AB(end)-F_AB(1));
                VLF.Specnn(i,j)     = nansum(Cnn_AB); %trapz(F_AB,Cnn_AB)/(F_AB(end)-F_AB(1));
                VLF.Rpn(i,j)        = trapz(F_AB,Rpn_AB)/(F_AB(end)-F_AB(1));
                VLF.roang(i,j)      = trapz(F_AB,roang_AB)/(F_AB(end)-F_AB(1));
                VLF.rocohp(i,j)     = trapz(F_AB,rocohp_AB)/(F_AB(end)-F_AB(1));
                VLF.rocohn(i,j)     = trapz(F_AB,rocohn_AB)/(F_AB(end)-F_AB(1));
                VLF.rophap(i,j)     = trapz(F_AB,rophap_AB)/(F_AB(end)-F_AB(1));
                VLF.rophan(i,j)     = trapz(F_AB,rophan_AB)/(F_AB(end)-F_AB(1));
                clear *_AB F minValue* close*
                
                if j < length(elev)
                    if elev(j+1) < z3(i)
                        uvlftb(i,1,:) = u1vlf;
                        uvlftb(i,2,:) = u2vlf;
                        vvlftb(i,1,:) = v1vlf;
                        vvlftb(i,2,:) = v2vlf;
                        elevtb(i,2) = elev(j);
                    end
                end
            elseif elev(j) > z1(i) || elev(j) < z3(i) % if the elevation is greater than Hs/2
                continue
            end 
        end  
    end
end

toc

% figure
% semilogy(Freq1,Cpp1,'k','linewidth',3)
% hold on
% semilogy(Freq1,Cppc1,'k','linewidth',0.25);
% semilogy(Freq1,Cnn1,'r','linewidth',3)
% hold on
% semilogy(Freq1,Cnnc1,'r','linewidth',0.25);
% grid
% xlabel('$\mathrm{Freq.}~(\mathrm{cph})$','interpreter','latex','fontsize',15)
% ylabel('$S_{w w}~\mathrm{(m^{2}s^{-2}/cph)}$','interpreter','latex','fontsize',15)

% figure
% plot(F,cohp,'k','linewidth',2)
% hold on
% plot(F,cohn,'r','linewidth',2)
% ylabel('$\mathrm{Rotary~Coherence}$','interpreter','latex','fontsize',15)
% xlabel('$\mathrm{Freq.}~(\mathrm{cph})$','interpreter','latex','fontsize',15)
% grid

% figure
% plot(F,phap,'k','linewidth',2)
% hold on
% plot(F,phan,'r','linewidth',2)
% ylabel('$\mathrm{Rotary~Phase}$','interpreter','latex','fontsize',15)
% xlabel('$\mathrm{Freq.}~(\mathrm{cph})$','interpreter','latex','fontsize',15)
            % grid

            
eval(['save -v7.3 ',sname1,' xshore',' ypt',' elev',' Cpp',' Cppc',' Cnn',' Cnnc',...
    ' Cppx',' Cppxc',' Fw',' Cnnx',' Cnnxc',' Frocoh',' rocohp',' rocohn',...
    ' rophap',' rophan',' Fropha',' Rpn',' roang'])
        % xshore = transect location (station p__)
        % ypt    = alongshore location (related to p__)
        % elev   = elevation array
        % Cpp    = positive (cw?) rotary auto-spectra
        % Cppc   = 95% confidence interval of positive rotary auto-spectra
        % Cnn    = negative (ccw?) rotary auto-spectra
        % Cnnc   = 95% confidence interval of negative rotary auto-spectra
        % Cppx   = positive cross-spectra from 2 elevations
        % Cppxc  = 95% confidence interval of positive rotary cross-spectra at 2 elevations
        % Cnnx   = negative cross-spectra from 2 elevations
        % Cnnxc  = 95% confidence interval of negative rotary cross-spectra at 2 elevations
        % Fw     = frequency for rotary spectras
        % Frocoh = frequency for coherence
        % rochop = coherence of postivie rotary spectras
        % rochon = coherence of negative rotary spectras
        % rophap = phase of postive rotary spectras
        % rophan = phase of negative rotaroy spectras
        % Fropha = frequency phase of rotary spectras
        % Rpn    = ratio of positive and negative rotary spectras at all frequencies
eval(['save -v7.3 ',sname2,' xshore',' ypt',' elev',' Cuu',' Cuuc',' Cvv',' Cvvc',...
    ' Cux',' Cvx',' Cuxc',' Cvxc',' Fu',' Fv',' cohu',' cohv',' phau',' phav',' uurms',' vvrms',' uvlf',' vvlf',' uvlftb',' vvlftb',' elevtb'])
        % xshore = transect location (station p__)
        % ypt    = alongshore location (related to p__)
        % elev   = elevation array
        % Cuu    = auto-spectra cross-shore velocity
        % Cuuc   = 95% confidence interval of auto-spectra cross-shore velocity
        % Cvv    = auto-spectra alongshore velocity
        % Cvvc   = 95% confidence interval of auto-spectra alongshore velocity
        % Cux    = cross-spectra from 2 elevations of cross-shore velocity
        % Cuxc   = 95% confidence interval of cross-spectra from 2 elevations of cross-shore velocity
        % Cvx    = cross-spectra from 2 elevations of alongshore velocity
        % Cvxc   = 95% confidence interval of cross-spectra from 2 elevations of alongshore velocity
        % Fu     = frequency for cross-shore spectra
        % Fv     = frequency for alonghore spectra
        % cohu   = coherence of cross-shore auto-spectras
        % cohv   = coherence of alongshore auto-spectras
        % phau   = phase of cross-shore auto-spectras
        % phav   = phase of alongshore auto-spectras
eval(['save -v7.3 ',sname3,' xshore',' ypt',' elev',' VLF',' Fboundspec',' Fboundlp']) %' rocoherence_p',' rocoherence_n',' rophase_p',' rophase_n',' Rpn',' Specpp',' Specnn'])
        % xshore = transect location (station p__)
        % ypt    = alongshore location (related to p__)
        % elev   = elevation array
        % REST ARE FROM Fbound(1)<f<Fbound(2) (VLF)
        % rocoherence_p = positive rotary spectra coherence in VLFs
        % rocoherence_n = negative rotary spectra coherence in VLFs
        % rophase_p     = postive rotary spectra phase in VLFs
        % rophase_n     = negative rotary spectra phase in VLFs
        % Rpn           = rotary spectra coefficient in VLFs
        % Specpp        = average positive rotary spectra in VLFs
        % Specnn        = average negative rotary spectra in VLFs
        % coherence_u   = cross-shore coherence in VLFs
        % coherence_v   = alongshore velocity spectra coherence in VLFs
        % phase_u       = cross-shore velocity spectra phase in VLFs
        % phase_v       = alongshore velocity spectra phase in VLFs
        % Specuu        = cross-shore velocity rotary spectra in VLFs
        % Specvv        = alongshore velocity rotary spectra in VLFs
        % roang         = mean orientation rotary spectra in VLFs
% eval(['save -v7.3 ',sname4,' xshore',' ypt',' PK'])%' elev',' coherence_u',' coherence_v',' phase_u',' phase_v',' Specuu',' Specvv'])
        % xshore = transect location (station p__)
        % ypt    = alongshore location (related to p__)
        % elev   = elevation array
        % REST ARE peak incident wave frequency
        % rocoherence_p = positive rotary spectra coherence in peak incident wave frequency
        % rocoherence_n = negative rotary spectra coherence in peak incident wave frequency
        % rophase_p     = postive rotary spectra phase in peak incident wave frequency
        % rophase_n     = negative rotary spectra phase in peak incident wave frequency
        % Rpn      = rotary spectra coefficient in peak incident wave frequency
        % Specpp        = average positive rotary spectra in peak incident wave frequency
        % Specnn        = average negative rotary spectra in peak incident wave frequency
        % coherence_u   = cross-shore coherence in peak incident wave frequency
        % coherence_v   = alongshore velocity spectra coherence in peak incident wave frequency
        % phase_u       = cross-shore velocity spectra phase in peak incident wave frequency
        % phase_v       = alongshore velocity spectra phase in peak incident wave frequency
        % Specuu        = cross-shore velocity rotary spectra in peak incident wave frequency
        % Specvv        = alongshore velocity rotary spectra in peak incident wave frequency
        % roang         = mean orientation rotary spectra in peak incident wave frequency
        
eval(['save -v7.3 ',sname4,' xshore',' ypt',' uvlftb',' vvlftb',' elevtb'])
 
