function calc_means_fulldomain(savefolder,simno,tpos,tend)
% This code will read through RAW SWASH .mat output to get water level, breaking and
% velocity components to be stored in a concatenated format
% INPUT:
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tpos: start time for calculating time-averages parameters
% tend: end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
% OUTPUT:
% sim#_watlev_mean.mat: time-averaged waterlevel for full domain
% sim#_velocity_mean.mat: time-averaged velocity for full domain
% sim#_vorticity_mean.mat: time-averaged vorticity for full domain
% sim#_cross-shore_param.mat: alongshore mean time-averaged parameters

display('Start calc_means_fulldomain')

%% STEP 1: Load .mat files processed processed in past step

load([savefolder,'sim',simno,'_domain.mat']);
F1 = matfile([savefolder,'sim',simno,'_velocity.mat']);
F2 = matfile([savefolder,'sim',simno,'_waterlevel.mat']);

%% STEP 2: Final File Names

sname1 = [savefolder,'sim',simno,'_velocity_mean.mat'];
sname2 = [savefolder,'sim',simno,'_vorticity_mean.mat'];
sname3 = [savefolder,'sim',simno,'_wlev_mean.mat'];
sname4 = [savefolder,'sim',simno,'_cross-shore_param.mat'];

%% STEP 3: Dimensions
% File details
x = length(xp(1,:)); % size x-dimension
y = length(yp(:,1)); % size y-dimension

%% STEP 4: Load specific time range

vel_u = squeeze(F1.vel_u(:,:,tpos:tend));
vel_v = squeeze(F1.vel_v(:,:,tpos:tend));
wlev = squeeze(F2.wlev(:,:,tpos:tend));

clear F1 F2

%% STEP 13: Calculate mean param

tic
for i = 1:y
    for j = 1:x
        vel_u_mean(i,j) = nanmean(squeeze(vel_u(i,j,:)));
        vel_v_mean(i,j) = nanmean(squeeze(vel_v(i,j,:)));
        vel_u_std(i,j) = nanstd(squeeze(vel_u(i,j,:)));
        vel_v_std(i,j) = nanstd(squeeze(vel_v(i,j,:)));
        wlev_mean(i,j) = nanmean(squeeze(wlev(i,j,:)));
    end 
%     disp(i)
end
vort_mean      = curl(xp,yp,vel_u_mean,vel_v_mean);

disp(['Done calculating mean over fulldomain. Domain is ',num2str(i),' by ',num2str(j),'.'])

clear i j
toc

%% STEP 14: Multiply times the beach

% vel_u_mean         = vel_u_mean.*beach;
% vel_v_mean         = vel_v_mean.*beach;
% vel_u_std          = vel_u_std.*beach;
% vel_v_std          = vel_v_std.*beach;
% vort_mean_from_vel = vort.*beach;
% vort_mean          = vort_mean.*beach;
% wlev_mean          = wlev_mean.*beach;

%% STEP 15: Cross-shore means

vel_u_mean_xshore         = nanmean(vel_u_mean,1)';
vel_v_mean_xshore         = nanmean(vel_v_mean,1)';
vel_u_std_xshore          = nanmean(vel_u_std,1)';
vel_v_std_xshore          = nanmean(vel_u_std,1)';
wlev_mean_xshore          = nanmean(wlev_mean,1)';
vort_mean_xshore          = nanmean(vort_mean,1)';
xp_xshore                 = squeeze(xp(1,:))';
h_xshore                  = nanmean(h,1)';

disp('Done calculating cross-shore mean values.')

%% STEP 16: Export Data

tic
eval(['save -v7.3 ',sname1,' vel_u_mean',' vel_u_std',' vel_v_mean',' vel_v_std']);
eval(['save -v7.3 ',sname2,' vort_mean']);
eval(['save -v7.3 ',sname3,' wlev_mean']);
eval(['save -v7.3 ',sname4,' vel_u_mean_xshore',' vel_v_mean_xshore',...
    ' vel_u_std_xshore',' vel_v_std_xshore',' wlev_mean_xshore',' xp_xshore',...
    ' h_xshore',' vort_mean_xshore'])

disp('Done saving and done with calc_means_fulldomain.')
toc

end
