function calc_sz_coh_pha_drop(savefolder,simno,cshore_transects,bins)
% This function will create plots of coherence and phase.
% INPUT:
% savefolder = location where processed data will be saved
% simno      = number of simulation that represents forcing
% cshore_transects = locations where interpolation has been completed
%
% OUTPUT: 
% sim##_coh_pha_drop.mat: file with the top, middle, and bottom values for 

%% STEP 0: Load domain files

Fdom    = load([savefolder,'sim',simno,'_subgrid_domain.mat']);
h       = fliplr(Fdom.h);
xp      = fliplr(900-Fdom.xp)+50;
yp      = -244+Fdom.yp;
clear xdom

sname1  = [savefolder,'rotary_spec/sim',simno,'_coh_pha_drop.mat']

display('Start calc surfzone coherence and phase drop.')

%% STEP 1: 

param = {'ustd','vstd','uurms','vvrms','Specuu','Specvv','cohu','cohv','phau','phav','Specnn','Specpp','Rpn','rocohp','rocohn','rophap','rophan'};

for i = 1:length(cshore_transects)
    % pick one location where going to store data
    ypt         = cshore_transects(i);
    iy          = find(yp(:,i)==ypt);
    hp(i,:)     = h(iy,:)';
    
    % matfiles for coherence
    F1          = matfile([savefolder,'rotary_spec/sim',simno,'_VLF_spectra_and_rotary_y',num2str(ypt),'_VLF005.mat']);
    elev        = F1.elev;
    VLF         = F1.VLF;
    
    % find index of top middle and bottom of VLF resolution
    idx         = find_top_middle_bottom(VLF.cohu);
    
    % find the elevations associated with these chosen locations
    ztemp       = repmat(elev,1,length(xp(1,:)));
    z(i,:,:)    = find_avg_val(ztemp',idx,bins);
    
    % now store the data at these elevations
    for j = 1:length(param)
        eval([param{j},'(i,:,:) = find_avg_val(VLF.',param{j},',idx,bins);'])
    end
%     
%     % try integrating? then normalize by depth
%     for j = 1:length(param) 
%         eval(['integral.',param{j},'(i,:,:) = trapz(VLF.',param{j},',bins);'])
%     end
    clear F1 elev VLF idx ztemp j
end

% redo the domain for locations where the interpolation is resolved
yp      = repmat(cshore_transects',1,length(xp(1,:)));
xp      = repmat(xp(1,:),length(cshore_transects),1);

% take alongshore average
for j = 1:length(param)
    eval(['ashore_avg.',param{j},'= squeeze(nanmean(',param{j},',1));'])
    eval(['ashore_avg.',param{j},'_std = squeeze(nanstd(',param{j},',1));'])
end
ashore_avg.xp   = xp(1,:)';
ashore_avg.z    = squeeze(nanmean(z,1));

% % alongshore average drop
% for j = 1:length(param)
%     eval([param{j},'_drop = cat(3,squeeze(',param{j},'(:,:,2)-',param{j},'(:,:,1))',...
%         ', squeeze(',param{j},'(:,:,3)-',param{j},'(:,:,1)));'])
%     eval(['ashore_drop.',param{j},'= squeeze(nanmean(',param{j},'_drop,1));'])
% end

eval(['save -v7.3 ',sname1,' ',strjoin(param),' ashore_avg',' z',' xp',' yp',' hp'])

display('Done calc_sz_coh_pha_drop.')