function convert_swash_output_fulldomain_1grid(runfolder,savefolder,simno,tide)
%This function will read through RAW SWASH .mat output to get water level, 
% velocity, and domain components to be stored in a concatenated format.
% INPUT:
% runfolder: location where SWASH raw output is saved
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tide: tidal elevation put into SWASH simulation
% OUTPUT:
% sim#_waterlevel.mat: waterlevel for full domain every second
% sim#_velocity.mat: velocity for full domain every second
% sim#_vorticity.mat: vorticity for full domain every second
% sim#_domain.mat: full domain details

display('Start convert_swash_output_fulldomain_1grid')

%% STEP 1: Load files
count  = 0;
load([runfolder,'/BD15_sim',simno,'_domain.mat']);
duck_wat = load([runfolder,'/BD15_sim',simno,'_wat.mat']);
duck_u   = load([runfolder,'/BD15_sim',simno,'_u.mat']);
duck_v   = load([runfolder,'/BD15_sim',simno,'_v.mat']);

%% STEP 2: Saved Files
sname1 = [savefolder,'sim',simno,'_waterlevel.mat'];
sname2 = [savefolder,'sim',simno,'_velocity.mat'];
sname3 = [savefolder,'sim',simno,'_domain.mat'];
sname4 = [savefolder,'sim',simno,'_vorticity.mat'];

%% STEP 3: Dimensions
% File details
x = length(Xp(1,:)); % size x-dimension
y = length(Yp(:,1)); % size y-dimension

%% STEP 4: Create List of File Names
ducknames_watlev = fieldnames(duck_wat); % Copy all file names from duck_wat
ducknames_u = fieldnames(duck_u); % Copy all file names from duck_u
ducknames_v = fieldnames(duck_v); % Copy all file names from duck_v

%% STEP 5: Convert to 3D File
for i = 1:1:length(ducknames_watlev)-1
    count=count+1;
    eval(['wlev(:,:,',num2str(count),')=duck_wat.',char(ducknames_watlev{i}),';']);
    eval(['vel_u(:,:,',num2str(count),')=duck_u.',char(ducknames_u{i}),';']);
    eval(['vel_v(:,:,',num2str(count),')=duck_v.',char(ducknames_v{i}),';']);
end
clear i

%% STEP 6: Adjust tidal elevation for bathymetry
% To model tidal elevation, SWASH adjusts the bathymetry by shifting it up
% or down depending on the tidal elevation. We want the actually
% bathymetry, so this backs out the tide.
h = Botlev-tide;

%% STEP 7: Define where the beach is located
% This creates a matrix where everthing that is above the tidal elevation
% is converted to NaN
for i = 1:y
    for j = 1:x
        if Botlev(i,j)<tide;
            beach(i,j)=NaN;
        else beach(i,j)=1;
        end
    end
end
clear i j

%% STEP 7: Calculate velocity
for k = 1:length(vel_v(1,1,:))
    vort(:,:,k) = curl(Xp,Yp,vel_u(:,:,k),vel_v(:,:,k));
end
clear k

%% STEP 8: Rename and Define File Format 
xp    = double(Xp);
yp    = double(Yp);
beach = double(beach);
h     = double(h);
wlev  = double(wlev);
vel_u = double(vel_u);
vel_v = double(vel_v);
vort  = double(vort);

%% STEP 9: Clear Variables
clearvars u v count duck_uv duck_wat x y...
    ducknames_watlev ducknames_u ducknames_v Xp Yp Botlev

display('Ready to save.')

%% STEP 10: Save Variables

eval(['save -v7.3 ',sname1,' wlev'])
eval(['save -v7.3 ',sname2,' vel_u',' vel_v']);
eval(['save -v7.3 ',sname3,' xp',' yp',' h',' beach']);
eval(['save -v7.3 ',sname4,' vort'])

display('Done with convert_swash_output_fulldomain_1grid.')

clear sname1 sname2 sname3 sname4

end
