function convert_swash_output_subgrid(runfolder,savefolder,simno,tide,layers)
% This function will read through RAW SWASH .mat output for subgrid in 2 grids 
% to get water level, velocity, and domain components to be stored in a concatenated format.
% INPUT:
% runfolder: location where SWASH raw output is saved.
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tide: tidal elevation put into SWASH simulation
% layers: number of layers in simulation
% OUTPUT:
% sim#_waterlevel.mat: waterlevel for full domain every second every layer
% sim#_velocity.mat: velocity for full domain every second every layer
% sim#_vorticity.mat: vorticity for full domain every second every layer
% sim#_domain.mat: full domain details

display('Start convert_swash_output_subgrid')

%% STEP 1: Saved Files
sname1 = [savefolder,'sim',simno,'_subgrid_waterlevel.mat'];
sname2 = [savefolder,'sim',simno,'_subgrid_vel_layer.mat'];
sname3 = [savefolder,'sim',simno,'_subgrid_domain.mat'];
sname4 = [savefolder,'sim',simno,'_subgrid_vorticity.mat'];


%% STEP 2a: Load files
subno = '1';
count  = 0;

load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_domain.mat']);
duck_wat = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_wat.mat']);
duck_u   = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_uk.mat']);
duck_v   = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_vk.mat']);
duck_z   = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_zk.mat']);

%% STEP 2b: Dimensions
% File details
x = length(Xp(1,:)); % size x-dimension
y = length(Yp(:,1)); % size y-dimension

%% STEP 2c: Create List of File Names
% List of file names
ducknames_watlev = fieldnames(duck_wat); % Copy all file names from duck_wat
ducknames_u = fieldnames(duck_u); % Copy all file names from duck_uv
ducknames_v = fieldnames(duck_v);
ducknames_z = fieldnames(duck_z);

%% STEP 2d: Convert to 4D File
count = 0;
count2 = 0;
count3 = 0;
for i = 1:1:length(ducknames_watlev)-1
    count=count+1;
    eval(['wlev(:,:,',num2str(count),')=duck_wat.',char(ducknames_watlev{i}),';']);
    for j = 1:layers
        count2 = count2+1;
        eval(['vel_u(:,:,',num2str(j),',',num2str(count),')=duck_u.',char(ducknames_u{count2}),';']);
        eval(['vel_v(:,:,',num2str(j),',',num2str(count),')=duck_v.',char(ducknames_v{count2}),';']);
    end
    for k = 1:(layers+1)
        count3 = count3+1;
        eval(['zk(:,:,',num2str(k),',',num2str(count),')=duck_z.',char(ducknames_z{count3}),';']);
    end
end
clear i j

%% STEP 2e: Adjust tidal elevation for bathymetry
% To model tidal elevation, SWASH adjusts the bathymetry by shifting it up
% or down depending on the tidal elevation. We want the actually
% bathymetry, so this backs out the tide.
h = Botlev-tide;

%% Step 2f: Define where the beach is located
for i = 1:y
    for j = 1:x
        if Botlev(i,j)<tide;
            beach(i,j)=NaN;
        else beach(i,j)=1;
        end
    end
end
clear i j

%% STEP 2g: Calculate velocity
for k = 1:length(vel_v(1,1,1,:))
    for i = 1:length(vel_v(1,1,:,1))
        vort(:,:,i,k) = curl(Xp,Yp,vel_u(:,:,i,k),vel_v(:,:,i,k));
    end
end

clear k i

%% STEP 2h: Rename and Define File Format 
xp_1    = double(Xp);
yp_1   = double(Yp);
beach_1 = double(beach);
h_1     = double(Botlev);
% t_1     = double((0:1:T)');
wlev_1  = double(wlev);
vel_u_1 = double(vel_u);
vel_v_1 = double(vel_v);
vort_1  = double(vort);
zk_1    = double(zk);
display('done with first section')

%% STEP 2i: Clear Variables
clearvars u v count count2 count3 i duck_uv duck_wat x y ii...
    ducknames_watlev ducknames_u ducknames_v ducknames_z Xp Yp Botlev...
    wlev vel_u vel_v vort zk

%% STEP 3a: Load files
subno = '2';
count  = 0;
duck_wat = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_wat.mat']);
duck_u   = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_uk.mat']);
duck_v   = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_vk.mat']);
duck_z   = load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_zk.mat']);
load([runfolder,'/BD15_sim',simno,'_subgrid',subno,'_domain.mat']);

%% STEP 3b: Create List of File Names
% List of file names
ducknames_watlev = fieldnames(duck_wat); % Copy all file names from duck_wat
ducknames_u = fieldnames(duck_u); % Copy all file names from duck_uv
ducknames_v = fieldnames(duck_v);
ducknames_z = fieldnames(duck_z);

%% STEP 3c: Dimensions
% File details
x = length(Xp(1,:)); % size x-dimension
y = length(Yp(:,1)); % size y-dimension

%% STEP 3d: Convert to 4D File
count = 0;
count2 = 0;
count3 = 0;
for i = 1:1:length(ducknames_watlev)-1
    count=count+1;
    eval(['wlev(:,:,',num2str(count),')=duck_wat.',char(ducknames_watlev{i}),';']);
    for j = 1:layers
        count2 = count2+1;
        eval(['vel_u(:,:,',num2str(j),',',num2str(count),')=duck_u.',char(ducknames_u{count2}),';']);
        eval(['vel_v(:,:,',num2str(j),',',num2str(count),')=duck_v.',char(ducknames_v{count2}),';']);
    end
    for k = 1:(layers+1)
        count3 = count3+1;
        eval(['zk(:,:,',num2str(k),',',num2str(count),')=duck_z.',char(ducknames_z{count3}),';']);
    end
end
clear i j

%% STEP 3e: Adjust tidal elevation for bathymetry
% To model tidal elevation, SWASH adjusts the bathymetry by shifting it up
% or down depending on the tidal elevation. We want the actually
% bathymetry, so this backs out the tide.
h = Botlev-tide;

%% Step 3f: Define where the beach is located
for i = 1:length(Botlev(:,1))
    for j = 1:length(Botlev(1,:))
        if Botlev(i,j)<tide;
            beach(i,j)=NaN;
        else beach(i,j)=1;
        end
    end
end
clear i j

%% STEP 3g: Calculate velocity
for k = 1:length(vel_v(1,1,1,:))
    for i = 1:length(vel_v(1,1,:,1))
        vort(:,:,i,k) = curl(Xp,Yp,vel_u(:,:,i,k),vel_v(:,:,i,k));
    end
end
clear k i

%% STEP 3h: Rename and Define File Format 
xp_2    = double(Xp);
yp_2   = double(Yp);
beach_2 = double(beach);
h_2     = double(Botlev);
wlev_2  = double(wlev);
vel_u_2 = double(vel_u);
vel_v_2 = double(vel_v);
vort_2  = double(vort);
zk_2    = double(zk);
display('done with second section')

%% STEP 3i: Clear Variables
clearvars u v count count2 count3 i duck_uv duck_wat x y ii...
    ducknames_watlev ducknames_u ducknames_v ducknames_z Xp Yp Botlev...
    wlev vel_u vel_v vort zk

display('Ready to combine grids.')
%% STEP 4: Add matricies together
xp    = cat(2,xp_1,xp_2);
yp    = cat(2,yp_1,yp_2);
beach = cat(2,beach_1,beach_2);
h     = cat(2,h_1,h_2);
wlev  = cat(2,wlev_1,wlev_2);
vel_u = cat(2,vel_u_1,vel_u_2);
vel_v = cat(2,vel_v_1,vel_v_2);
vort  = cat(2,vort_1,vort_2);
zk    = cat(2,zk_1,zk_2);

display('Ready to save.')

%% STEP 5: Save Variables

eval(['save -v7.3 ',sname1,' wlev'])
eval(['save -v7.3 ',sname2,' vel_u',' vel_v',' zk']);
eval(['save -v7.3 ',sname3,' xp',' yp',' h',' beach']);
eval(['save -v7.3 ',sname4,' vort'])

display('Done convert_swash_output_subgrid.')

end

