function estimate_Hsig_fulldomain(savefolder,simno,tpos,tend,WL,OL)
% This code will estimate significant wave height across the domain by
% using a provided time range. 
% INPUT:
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tpos: start time for calculating time-averages parameters
% tend: end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
% WL:    Window length for calculated spectra, Steve=128, FRF=256
% OL:    Overlap length for calculated spectra, Steve=128*0.75, FRF = 128
% OUTPUT:
% sim#_spectra.mat: .mat file with the spectra at each location
% sim#_Hs.mat: significant wave height calc from 4std and spectra
% sim#_period.mat: peak and energy spectra
%
% Note: To reduce time of processing, comment out the section that uses the
% spectra to calculate Hsig. Instead only use Hsig_4st. Then make sure you
% change the saved files as well.

display('Start estimate_Hsig_fulldomain.')

%% Step 1: Load data

load([savefolder,'sim',simno,'_domain.mat']);
F1 = matfile([savefolder,'sim',simno,'_waterlevel.mat']);

sname1 = [savefolder,'sim',simno,'_spectra.mat'];
sname2 = [savefolder,'sim',simno,'_Hs.mat'];
sname3 = [savefolder,'sim',simno,'_period.mat'];
%% STEP 2: Choose a location where to extract sea-surface
xp = fliplr(900-xp)+50;
yp = -244+yp;

x_grid = length(xp(1,:)); % alongshore
y_grid = length(yp(:,1)); % cross-shore
x_domain = max(xp(1,:));
y_domain = max(yp(:,1));
dx = x_domain/(x_grid-1);
dy = y_domain/(y_grid-1);

dT      = 1;                    % Time interval
time    = tpos:dT:tend;     % 1-second output
wlev   = squeeze(F1.wlev(:,:,tpos:tend));

%% STEP 3: Remove the mean
for i = 1:y_grid;
    for j = 1:x_grid;
        wlev_mean(i,j) = nanmean(wlev(i,j,:));
    end
end
count = 0;
for k = 1:length(time)
    count = count+1;
    z(:,:,count) = wlev(:,:,k)-wlev_mean(:,:);
end

%% STEP 4:

for i = 1:x_grid;
    for j = 1:y_grid;
        if h(j,i)>0;
            z_dummy = squeeze(z(j,i,:));
            if nansum(isnan(z_dummy))==0
                [See(j,i,:),f(j,i,:)] = pwelch(z_dummy,WL,OL,[],1/dT); % for 129 freq
                %[See(j,i,:),f(j,i,:)] = pwelch(z_dummy,128,128*0.75,128,1/dT) for 65 freq  %Uses Welch's periodogram method
                %         See_domain = See(i,j);
                %         f_domain = f(i,j);
                m = find(f(j,i,:)>=0.05 & f(j,i,:)<=0.35);
                f_dummy = squeeze(f(j,i,m(1):m(end)));
                See_dummy = squeeze(See(j,i,m(1):m(end)));
                Hs(j,i) = 4*sqrt(trapz(f_dummy,See_dummy));
                [M,I] = max(See_dummy);
                fmax = f_dummy(I);
                Tp(j,i) = 1/fmax;
                Te(j,i) = (trapz(f_dummy,See_dummy))/(trapz(f_dummy,f_dummy.*See_dummy));
                clear z_dummy M I fmax f_dummy See_dummy m
            else
                Hs(j,i) = NaN;
                Tp(j,i)  = NaN;
                Te(j,i)  = NaN;
                f(j,i,:) = NaN;
                See(j,i,:) = NaN;
            end
        else
            Hs(j,i) = NaN;
            Tp(j,i)  = NaN;
            Te(j,i)  = NaN;
            f(j,i,:) = NaN;
            See(j,i,:) = NaN;
        end
    end
disp(i)    
end

zs=nanstd(z,[],3);
Hs_4std=4*sqrt(zs.^2);
% Hs = Hs_4std;

display('Ready to save Hsig')

eval(['save -v7.3 ',sname1,' f',' See']);
eval(['save -v7.3 ',sname2,' Hs',' Hs_4std']);
% eval(['save -v7.3 ',sname2,' Hs_4std']);
eval(['save -v7.3 ',sname3,' Tp',' Te']);

display('Done saving estimate_Hsig_fulldomain.')
end