function [paramout] = find_avg_val(param,idx,bins);
% This function will find the top, bottom and middle elevation of the given
% parameter in the SWASH domain
% INPUT:
% param = any parameter that you're trying to find resolved top, middle,
% and bottom elevation that it is resolved to. Needs to be xp-by-elev where
% the cross-shore locatino is increasing from 1 and the elevation is
% decreading from 1.
% idx = index of the top, middle, bottom
% bins = how many elevations want to avg over
% 
% OUTPUT: 
% paramout(t m b, cross-shore): avg param value of top location, middle location, bottom 
% location where the string will be 3xlength(xshore)
% 

for i = 1:length(param(:,1))
    if sum(~isnan(idx(:,i)))>0
        t(i)      = nanmean(param(i,idx(1,i):idx(1,i)+(bins-1))); % avg where it is top
        m(i)      = nanmean(param(i,(idx(2,i)-(bins/2-0.5)):(idx(2,i)+(bins/2-0.5)))); % avg where im is middle
        b(i)      = nanmean(param(i,idx(3,i)-(bins-1):idx(3,i))); % avg where ib is bottom
    else
        t(i)    = NaN;
        m(i)    = NaN;
        b(i)    = NaN;
    end
end

paramout = [t' m' b'];