function [idx] = find_top_middle_bottom(param);
% This function will find the top, bottom and middle elevation of the given
% parameter in the SWASH domain
% INPUT:
% param = any parameter that you're trying to find resolved top, middle,
% and bottom elevation that it is resolved to. Needs to be xp-by-elev where
% the cross-shore locatino is increasing from 1 and the elevation is
% decreading from 1. 
% 
% OUTPUT: 
% idx(it im ib, cross-shore): index of top location, middle location, bottom 
% location where the string will be 3xlength(xshore)
% 

temp = ~isnan(param);

xshore = length(param(:,1));

for i = 1:xshore
    if sum(temp(i,:))>0
        it(i) = find(~isnan(param(i,:)),1,'first');
        ib(i) = find(~isnan(param(i,:)),1,'last');
        im(i) = it(i)+round((ib(i)-it(i))/2);
    else
        it(i) = NaN;
        ib(i) = NaN;
        im(i) = NaN;
    end
end

idx = [it; im; ib];

end
