function interp_subgrid_eulerian_transect_crossshore_BDinst(savefolder,frffolder,simno,tpos,tend,layers,tide,crossshore_array,elev)
% This code will read through RAW SWASH .mat output to get water level, breaking and
% velocity components to be stored in a concatenated format
% INPUT:
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tpos: start time for calculating time-averages parameters
% tend: end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
% layers: number of layers in simulation
% tide: tidal elevation on frfdate
% elev: elevations which the layers will interpolate to
% OUTPUT:
% sim#_watlev_mean.mat: time-averaged waterlevel for subgrid
% sim#_zk_mean.mat: time-averaged layer boundary for subgrid
% sim#_velocity_mean.mat: time-averaged velocity per layer for subgrid
% sim#_vorticity_mean.mat: time-averaged vorticity per layer for subgrid
% sim#_cross-shore_param.mat: alongshore mean time-averaged parameters



%
%
% Check below

% note to self: for voriticty, compute the curl around the pt you're
% interested in. So bascially don't want to look at the edges of the
% matrix.
% 
% 
% 
% 
% 
% 
% 
% 
% 
%% STEP 1: Load .mat files for subgrid

display('Start calc_means_subgrid_eularian.m')

load([frffolder,'onshore_point_measurements.mat']);
load([savefolder,'sim',simno,'_subgrid_domain.mat']);
F1 = matfile([savefolder,'sim',simno,'_subgrid_vel_layer.mat']);
F2 = matfile([savefolder,'sim',simno,'_subgrid_waterlevel.mat']);
F3 = matfile([savefolder,'sim',simno,'_subgrid_vorticity.mat']);

%% STEP 2: Final File Names

sname1 = [savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_crossshore_transects_p',num2str(crossshore_array),'.mat']; % vel,vort,wlev,z,x,y
sname2 = [savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_mean_crossshore_transects_p',num2str(crossshore_array),'.mat'];
sname3 = [savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_mean_p',num2str(crossshore_array),'.mat'];

%% STEP 3: Adjust domain and specificy dimensions
% xp = fliplr(900-xp)+50;
yp = -244+yp;

x = length(xp(1,:)); % size x-dimension
y = length(yp(:,1)); % size y-dimension



%% STEP 4: Find the alongshore location to interpolate data
if crossshore_array == 10
    station = {'p11';'p12';'p13';'p14'};
elseif crossshore_array == 20
    station = {'p21';'p22';'p23';'p24'};
elseif crossshore_array == 80
    station = {'p83';'p84'};
end

if crossshore_array == 10;
    x_pt = [On.x11, On.x12, On.x13, On.x14];
    y_pt = [On.y11, On.y12, On.y13, On.y14];
    y_mean = nanmean(y_pt);
elseif crossshore_array == 20;
    x_pt = [On.x21, On.x22, On.x23, On.x24];
    y_pt = [On.y21, On.y22, On.y23, On.y24];
    y_mean = nanmean(y_pt);
elseif crossshore_array == 80;
    x_pt = [On.x83, On.x84];
    y_pt = [On.y83, On.y84];
    y_mean = nanmean(y_pt);
end 

% Find the index of the alongshore location of the mean instrument location
% This will also include two extra indicies on either side of the indicies
% that the mean instrument location is. This will help with calculating the
% vorticity.
A = repmat(y_mean,y,1); % make matrix of repeating y_mean values
[minValue,close_i]  = nanmin(abs(A-yp(:,1))); % find the location of the minimum dif between the y_mean and the alongshore coordinates
% make a 4x1 matrix of the indicies of the alongshore coordinates, centered
% around y_mean
if y_mean < yp(close_i,1)
    yi = [close_i-2;close_i-1;close_i;close_i+1];
elseif y_mean > yp(close_i,1)
    yi = [close_i-1;close_i;close_i+1;close_i+2];
end
% check that this is done right
y_mean
ypt = yp(yi,1)

%%%% edit below don't need this because there is no flipping
% for i = 1:length(locx)
%     y_loc_frf           = find(x(1,:)==locx(i)); % find the grid location of the cross-shore specified locations
%     x_loc_check_frf(i)  = x(1,x_loc_frf); % this is a check to make sure you are saving the right location is chosen in the frf domain
%     x_loc_check_sim(i)  = xp(1,x_actual-x_loc_frf); % this is another test to check if the right location is chosen in the simulation domain
%     x_loc_sim(i)        = x_actual-x_loc_frf;  % find the grid location in the simulation format
% end


%% STEP 3: Define time which velocity will be calculated for
vel_uk  = squeeze(F1.vel_u(yi,:,:,tpos:tend));
vel_vk  = squeeze(F1.vel_v(yi,:,:,tpos:tend));
zk     = squeeze(F1.zk(yi,:,:,tpos:tend));
wlev   = squeeze(F2.wlev(yi,:,tpos:tend));
% vort   = squeeze(F3.vort(:,:,:,tpos:tend));
time = (tend-tpos)+1; % The length of all the strings are 1 longer than tpos-tend


%% STEP 6: Time to interp the data to specified layers
% Note that h is alwasy positive for bathymetry below mean sea level
% however, zk is negative for below sea level. This is the same coordinate
% system as elev (looking for negative values). 

tic
for i = 1:length(yi)
    for j = 1:x
        for l = 1:time
            for k = 1:layers
                zk_mid(i,j,k,l) = ((zk(i,j,k,l)+zk(i,j,k+1,l))/2);%+tide;
            end
            for m = 1:length(elev)
                if h(yi(i),j) >= -elev(m)
                    temp_zk = squeeze(zk_mid(i,j,:,l));
                    temp_uk = squeeze(vel_uk(i,j,:,l));
                    temp_vk = squeeze(vel_vk(i,j,:,l));
                    test_if  = (nansum(temp_uk)+nansum(temp_vk))*nansum(~isnan(temp_zk));
                    if test_if == 0;
                        vel_uk_int(i,j,m,l) = NaN;
                        vel_vk_int(i,j,m,l) = NaN;
                    else
                        vel_uk_int(i,j,m,l) = interp1(temp_zk,temp_uk,elev(m),'linear','extrap');
                        vel_vk_int(i,j,m,l) = interp1(temp_zk,temp_vk,elev(m),'linear','extrap');
                        %                     vort_int(i,j,m,l)   = curl(xp(i,j),yp(i,j),vel_uk_int(i,j,m,l),vel_vk_int(i,j,m,l));
                    end
                elseif h(yi(i),j) <= -elev(m)
                    vel_uk_int(i,j,m,l) = NaN;
                    vel_vk_int(i,j,m,l) = NaN;
                    %                     vort_int(i,j,m,l)   = NaN;
                end
            end
        end
    end
    display(num2str(yi(i)))
end

for i = 1:time
   for j = 1:length(elev)
       vortk(:,:,j,i) = curl(xp(yi,:),yp(yi,:),vel_uk_int(:,:,j,i),vel_vk_int(:,:,j,i));
   end
end

clear zk_mid
eval(['save -v7.3 ',sname1,' vel_uk_int',' vel_vk_int',' vortk',' elev',' y_mean',' ypt',' crossshore_array',' wlev']);

toc
display('Saved interpolated data.')
%% STEP 7: Calculate mean param
tic 

for i = 1:length(yi)
    for j = 1:x
         wlev_mean(i,j) = nanmean(squeeze(wlev(i,j,:)));
        for k = 1:length(elev)
            % mean
            vel_uk_mean(i,j,k) = nanmean(squeeze(vel_uk_int(i,j,k,:)));
            vel_vk_mean(i,j,k) = nanmean(squeeze(vel_vk_int(i,j,k,:)));
            vortk_mean(i,j,k) = nanmean(squeeze(vortk(i,j,k,:)));
            % standard deviation
            vel_uk_std(i,j,k) = nanstd(squeeze(vel_uk_int(i,j,k,:)));
            vel_vk_std(i,j,k) = nanstd(squeeze(vel_vk_int(i,j,k,:)));
            vortk_std(i,j,k) = nanstd(squeeze(vortk(i,j,k,:)));
        end
    end
end 


% wlev = wlev-tide;
% h = h-tide;
% elev = elev-tide;

eval(['save -v7.3 ',sname2,' vel_uk_mean',' vel_uk_std',' vel_vk_mean',' vel_vk_std',...
    ' vortk_mean',' vortk_std',' wlev_mean',' elev',' ypt',' y_mean',' crossshore_array']);

display(['Done calculating and savubg mean over fulldomain. Domain is ',num2str(i),' by ',num2str(j),'.'])

clear i j k l
toc

%% STEP 8: Interpolate the velocity and vorticity to specific location

wlev_xshore_mean = (interp1(yp(yi,1),wlev_mean,y_mean))';
for i = 1:length(elev)
    % mean
    vel_uk_xshore_mean(:,:,i) = interp1(yp(yi,1),vel_uk_mean(:,:,i),y_mean);%repmat(y_mean,length(yp(1,:))));
    vel_vk_xshore_mean(:,:,i) = interp1(yp(yi,1),vel_vk_mean(:,:,i),y_mean);
    vortk_xshore_mean(:,:,i) = interp1(yp(yi,1),vortk_mean(:,:,i),y_mean);
    % std
    vel_uk_xshore_std(:,:,i) = interp1(yp(yi,1),vel_uk_std(:,:,i),y_mean);%repmat(y_mean,length(yp(1,:))));
    vel_vk_xshore_std(:,:,i) = interp1(yp(yi,1),vel_vk_std(:,:,i),y_mean);
    vortk_xshore_std(:,:,i) = interp1(yp(yi,1),vortk_std(:,:,i),y_mean);
end

    % bathy
    h_xshore = interp1(yp(yi,1),h(yi,:),y_mean)';
    

vel_uk_xshore_mean = squeeze(vel_uk_xshore_mean(1,:,:));
vel_vk_xshore_mean = squeeze(vel_vk_xshore_mean(1,:,:));
vortk_xshore_mean = squeeze(vortk_xshore_mean(1,:,:));

vel_uk_xshore_std = squeeze(vel_uk_xshore_std(1,:,:));
vel_vk_xshore_std = squeeze(vel_vk_xshore_std(1,:,:));
vortk_xshore_std = squeeze(vortk_xshore_std(1,:,:));


display('ready to save the xshore mean files')

eval(['save -v7.3 ',sname3,' vel_uk_xshore_mean',' vel_vk_xshore_mean',...
    ' vel_uk_xshore_std',' vel_vk_xshore_std',' wlev_xshore_mean',...
    ' h_xshore',' vortk_xshore_mean',' vortk_xshore_std',' elev',' y_mean',' crossshore_array'])

display('done')

end
