function interp_subgrid_vel(savefolder,frffolder,simno,tpos,tend,layers,tide,elev,resx,resy)
% This code will read through RAW SWASH .mat output to get water level, breaking and
% velocity components to be stored in a concatenated format
% INPUT:
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tpos: start time for calculating time-averages parameters
% tend: end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
% layers: number of layers in simulation
% tide: tidal elevation on frfdate
% elev: elevations which the layers will interpolate to
% OUTPUT:
% sim#_watlev_mean.mat: time-averaged waterlevel for subgrid
% sim#_zk_mean.mat: time-averaged layer boundary for subgrid
% sim#_velocity_mean.mat: time-averaged velocity per layer for subgrid
% sim#_vorticity_mean.mat: time-averaged vorticity per layer for subgrid
% sim#_cross-shore_param.mat: alongshore mean time-averaged parameters



% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% clc
% clear all
% close all
% addpath(genpath('/data2/baker/SWASH/BATHYDuck15/codes/SWASH_analysis'));
% addpath(genpath('/data2/baker/MTOOLS'));
% frfpath  = '/data2/baker/Observations_BD15/data/';
% % path = '/Users/cmbaker9/Documents/Research/SWASH/BATHYDuck/';
% path  = '/Users/cmbaker9/Documents/Research/SWASH/BATHYDuck/';
% 
% %%%%%%%%%%%%%%%%%%%%%%%%% USER MODIFIABLE SECTION %%%%%%%%%%%%%%%%%%%%%%%%
% 
% % Simulation Details
% dateran= '19_04'; % month of simulation
% date   = '28-Oct-2015 00:00:00'; % date of forcing for simulation
% simno  = '19';    % arbritrary number that helps name simulations related to date
% time   = '7200'; % simulation time
% layers = 5;      % number of layers in simulation
% tide   = -0.320;  % tidal elevation in model run
% tpos   = 3601;   % start time for calculating time-averages parameters
% tend   = 7200;   % end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
% % fdomno = 2;      % number of .mat files the full domain is seperated in
% % subno  = 3;      % number of .mat files the subgrid is seperated in
% % Tp     = 7;  % peak period of observations from 11 m
% % id      = 1; % if it is idealized, put 1 (different subregion). if not idealized put [].
% BD       = 0;
% 
% % Consistant simulation folder name (same for run and data)
% simfolder    = ['sim',simno,'_',date(1:2),'-',date(4:6),'-',date(8:11),'_',date(13:14),'00/'];
% % simfolder = 'shore-normal_waves/';
% 
% % Run: simulation output location
% subfolder = 'try4_final/';%'sim42_channel_subgrid/';%[time,'_',num2str(layers),'_layers_PSlowvisc/']; 
% % runfolder     = [path,'runs/',dateran,'/',simfolder,subfolder,''];
% 
% % Data: processed simulation output location
% ssubfolder = [subfolder,''];%['sim',simno,'_',date(1:2),'-',date(4:6),'-',date(8:11),'_',date(13:14),'00/'];
% %[time,'_',num2str(layers),'_layers/'];
% savefolder = [path,'data/',simfolder,ssubfolder];
% % savefolder = runfolder;
% 
% % Observations: location of processed observations to compare with swash simulations
% frfsubfolder = '';
% frffolder = [frfpath,frfsubfolder];
% 
% 
% 
% % elev = flipud([-5:0.1:-0.1]');
% elev = [-0.25; -0.5; -0.75; -1; -2; -3];
% res = 6;
    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%






%% STEP 1: Load .mat files for subgrid

display('Start interp_subgrid_vel.m')

load([savefolder,'sim',simno,'_subgrid_domain.mat']);
F1 = matfile([savefolder,'sim',simno,'_subgrid_vel_layer.mat']);
F2 = matfile([savefolder,'sim',simno,'_subgrid_waterlevel.mat']);
F3 = matfile([savefolder,'sim',simno,'_subgrid_vorticity.mat']);

%% STEP 3: Adjust domain and specificy dimensions
xfrf    = fliplr(900-xp)+50;
yfrf    = -244+yp;
x       = length(xp(1,:)); % size x-dimension
y       = length(yp(:,1)); % size y-dimension

%% STEP 4a: Find the alongshore location to interpolate data
rangey              = yfrf(1,1):resy:yfrf(end,1);

yi                  = ismember(yfrf(:,1),rangey');  % find the grid location in the simulation format
yi                  = nonzeros(yi.*[1:length(yi)]');
y_loc_check_frf     = yfrf(yi,1) % this is a check to make sure you are saving the right location is chosen in the frf domain
y_loc_check_sim     = yp(yi,1)-244 % this is another test to check if the right location is chosen in the simulation domain
check               = ~ismember(y_loc_check_frf,y_loc_check_sim);
if sum(check) > 0
    display('Something isnt right in how the locations are choseb')
end

%% STEP 4b: Find cross-shore location to interp
rangex              = xfrf(1,1):resx:xfrf(1,end);

x_loc_frf           = ismember(xfrf(1,:),rangex);
x_loc_frf           = nonzeros(x_loc_frf.*[1:length(x_loc_frf)]);
xi                  = flipud(x-(x_loc_frf-1));
%x_loc_frf           = find(xfrf(1,:)==rangx); % find the grid location of the cross-shore specified locations
x_loc_check_frf     = xfrf(1,x_loc_frf); % this is a check to make sure you are saving the right location is chosen in the frf domain
%xi                  = x-(x_loc_frf-1);  % find the grid location in the simulation format
%xi                  = [xsim-range:xsim+range]; % pick locations around this for vorticity
x_loc_check_sim     = (900-xp(1,xi)+50); % this is another test to check if the right location is chosen in the simulation domain
check1              = ~ismember(x_loc_check_sim,x_loc_check_frf);
if sum(check1) > 0
    display('Something isnt right in how the locations are choseb')
end

% % Check to make sure above is correct output
% test        = squeeze(F1.vel_u(:,:,2,3600));
% fliptest    = fliplr(test);
% velsim      = test(:,xi);
% velfrf      = fliptest(:,x_loc_frf-1:x_loc_frf+1);
% dif         = fliplr(velsim)-velfrf

%% Remake domain and elevation for resolution

% xpt     = x_loc_frf(:,x_loc_frf);
xpt       = xp(yi,xi);

%ypt     = yfrf(yi,:);
ypt       = yp(yi,xi);

% find elevaitons at these locations
hpt         = h(yi,xi);

%% STEP 2: Final File Names

sname1 = [savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_resx',num2str(resx),'m.mat']; % vel,vort,wlev,z,x,y
sname2 = [savefolder,'elevation_interpolations/','sim',simno,'_vel_vort_mean_resx',num2str(resx),'m.mat'];

%% STEP 3: Define time which velocity will be calculated for

vel_uk  = squeeze(F1.vel_u(yi,xi,:,tpos:tend));
vel_vk  = squeeze(F1.vel_v(yi,xi,:,tpos:tend));
zk     = squeeze(F1.zk(yi,xi,:,tpos:tend));
wlev   = squeeze(F2.wlev(yi,xi,tpos:tend));
vort   = squeeze(F3.vort(yi,xi,:,tpos:tend));
time = (tend-tpos)+1; % The length of all the strings are 1 longer than tpos-tend

%% STEP 6: Time to interp the data to specified layers
% Note that h is alwasy positive for bathymetry below mean sea level
% however, zk is negative for below sea level. This is the same coordinate
% system as elev (looking for negative values). 

tic
for i = 1:length(yi)
    for j = 1:length(xi)
        for l = 1:time
            for k = 1:layers
                zk_mid(i,j,k,l) = ((zk(i,j,k,l)+zk(i,j,k+1,l))/2);%+tide;
            end
            for m = 1:length(elev)
                if h(yi(i),xi(j)) >= -elev(m) % this could also be hpt(i,j)
                    temp_zk = squeeze(zk_mid(i,j,:,l));
                    temp_uk = squeeze(vel_uk(i,j,:,l));
                    temp_vk = squeeze(vel_vk(i,j,:,l));
                    temp_vort = squeeze(vort(i,j,:,l));
                    test_if  = (nansum(temp_uk)+nansum(temp_vk))*nansum(~isnan(temp_zk));
                    if test_if == 0;
                        vel_uk_int(i,j,m,l) = NaN;
                        vel_vk_int(i,j,m,l) = NaN;
                        vort_int(i,j,m,l)   = NaN;
                    else
                        vel_uk_int(i,j,m,l) = interp1(temp_zk,temp_uk,elev(m),'linear','extrap');
                        vel_vk_int(i,j,m,l) = interp1(temp_zk,temp_vk,elev(m),'linear','extrap');
                        vort_int(i,j,m,l)   = interp1(temp_zk,temp_vort,elev(m),'linear','extrap');
%                         vort_int(i,j,m,l)   = curl(xp(i,j),yp(i,j),vel_uk_int(i,j,m,l),vel_vk_int(i,j,m,l));
                    end
                elseif h(yi(i),xi(j)) <= -elev(m) % this could also be hpt(i,j)
                    vel_uk_int(i,j,m,l) = NaN;
                    vel_vk_int(i,j,m,l) = NaN;
                    vort_int(i,j,m,l)   = NaN;
                end
            end
        end
    end
    display(num2str(ypt(i,1)))
end

% only use below if not subsampling because don't want to take curl of
% spread apart
% for i = 1:time
%    for j = 1:length(elev)
%        vortk(:,:,j,i) = curl(xp(yi,xi),yp(yi,xi),vel_uk_int(:,:,j,i),vel_vk_int(:,:,j,i));
%    end
% end

clear zk_mid
eval(['save -v7.3 ',sname1,' vel_uk_int',' vel_vk_int',' vort_int',' elev',' ypt',' xpt',' hpt',' resx',' resy',' wlev']);%vortk

toc
display('Saved interpolated data.')
%% STEP 7: Calculate mean param
tic 

for i = 1:length(yi)
    for j = 1:length(xi)
         wlev_mean(i,j) = nanmean(squeeze(wlev(i,j,:)));
        for k = 1:length(elev)
            % mean
            vel_uk_mean(i,j,k) = nanmean(squeeze(vel_uk_int(i,j,k,:)));
            vel_vk_mean(i,j,k) = nanmean(squeeze(vel_vk_int(i,j,k,:)));
            vortk_mean(i,j,k)  = nanmean(squeeze(vort_int(i,j,k,:)));
%             vortk_mean(i,j,k) = nanmean(squeeze(vortk(i,j,k,:)));
            % standard deviation
            vel_uk_std(i,j,k) = nanstd(squeeze(vel_uk_int(i,j,k,:)));
            vel_vk_std(i,j,k) = nanstd(squeeze(vel_vk_int(i,j,k,:)));
            vortk_std(i,j,k)  = nanstd(squeeze(vort_int(i,j,k,:)));
%             vortk_std(i,j,k) = nanstd(squeeze(vortk(i,j,k,:)));
        end
    end
end 


% wlev = wlev-tide;
% h = h-tide;
% elev = elev-tide;

eval(['save -v7.3 ',sname2,' vel_uk_mean',' vel_uk_std',' vel_vk_mean',' vel_vk_std',...
    ' vortk_mean',' vortk_std',' wlev_mean',' elev',' ypt',' xpt',' hpt',' resx',' resy']);

display(['Done calculating and savubg mean over fulldomain. Domain is ',num2str(i),' by ',num2str(j),'.'])

clear i j k l
toc

%% STEP 8: Interpolate the velocity and vorticity to specific location

% cent = length(yi)-(length(yi)-1)/2
% 
% wlev_yshore_mean = squeeze(wlev_mean(cent,:));
% for i = 1:length(elev)
%     % mean
%     vel_uk_yshore_mean(:,i) = squeeze(vel_uk_mean(cent,:,i));%repmat(y_mean,length(yp(1,:))));
%     vel_vk_yshore_mean(:,i) = squeeze(vel_vk_mean(cent,:,i));
%     vortk_yshore_mean(:,i) = squeeze(vortk_mean(cent,:,i));
%     % std
%     vel_uk_yshore_std(:,i) = squeeze(vel_uk_std(cent,:,i));%repmat(y_mean,length(yp(1,:))));
%     vel_vk_yshore_std(:,i) = squeeze(vel_vk_std(cent,:,i));
%     vortk_yshore_std(:,i) = squeeze(vortk_std(cent,:,i));
% end
% 
%     % bathy
%     h_yshore = h(ysim,:);


% display('ready to save the yshore mean files')
% 
% eval(['save -v7.3 ',sname3,' vel_uk_yshore_mean',' vel_vk_yshore_mean',...
%     ' vel_uk_yshore_std',' vel_vk_yshore_std',' wlev_yshore_mean',...
%     ' h_yshore',' vortk_yshore_mean',' vortk_yshore_std',' elev',' yloc'])
% 
% display('done')

% end
