function save_FRF_conditions(savefolder,frffolder,simno,date)
% This script will find the forcing conditions measured at the FRF during 
% the date and hour of forcing. This will save files with the measured bulk parameters
% as well as other parameters (e.g., spectra).
% INPUT:
% FRF measurments at 11-m water depth
% FRF measurments at 7-m water depth
% frffolder: location of saved data
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% OUTPUT:
% sim#_frf_bulkparam.mat: 11-m bulk wave parameters
% sim#_frf_spectra.mat: 6-m and 11-m spectra

display('Start save_FRF_conditions.m')

% STEP 1: Load data
frf_11 = load([frffolder,'off_11m.mat'])
subfrf = 'raw_data/';
fname1 = 'FRF-ocean_waves_awac-11m_201510.nc';
fname2 = 'FRF-ocean_waves_awac-6m_201510.nc';

% STEP 2: File save name
sname1 = [savefolder,'sim',simno,'_frf_bulkparam.mat'];
sname2 = [savefolder,'sim',simno,'_frf_spectra.mat'];

% STEP 3: Find bulk parameters
k  = find(frf_11.time==datenum(date));
Hsig = frf_11.Hsig(k);
Tp   = frf_11.Tp(k);
dir  = frf_11.dir(k);
sprd = frf_11.sprd(k);
tide = frf_11.tide(k);

% STEP 4: FRF spectra at 11-m
f_11 = ncread([frffolder,subfrf,fname1],'waveFrequency');
See_off = ncread([frffolder,subfrf,fname1],'waveEnergyDensity');
Hsig_off = ncread([frffolder,subfrf,fname1],'waveHs');
t_off = ncread([frffolder,subfrf,fname1],'time');
t_11 = find(round(t_off,4)==round(datenum(date),4));
t_11 = t_11/24/3600+datenum(1970,01,01,0,0,0);
t_11 = t_11-0.1667;
See_11 = See_off(:,t_11)
Hs_11spec = 4*sqrt(trapz(f_11,See_11));
Hs_11frf = Hsig_off(t_11);

clear See_off Hsig_off t_off

f_06 = ncread([frffolder,subfrf,fname1],'waveFrequency');
See_off = ncread([frffolder,subfrf,fname1],'waveEnergyDensity');
Hsig_off = ncread([frffolder,subfrf,fname1],'waveHs');
t_off = ncread([frffolder,subfrf,fname1],'time');
t_06 = find(round(t_off,4)==round(datenum(date),4));
t_06 = t_06/24/3600+datenum(1970,01,01,0,0,0);
t_06 = t_06-0.1667;
See_06 = See_off(:,t_06)
Hs_06spec = 4*sqrt(trapz(f_06,See_06));
Hs_06frf = Hsig_off(t_06);

clear See_off Hsig_off t_off

eval(['save -v7.3 ',sname1,' Hsig',' Tp',' dir',' sprd',' tide'])
eval(['save -v7.3 ',sname1,' t_11',' Hs_11frf',' See_11',' f_11',' Hs_11spec'...
    ' t_06',' Hs_06frf',' See_06',' f_06',' Hs_06spec'])

display('Done save_FRF_conditions.m.')
end
