function save_spectra(savefolder,frffolder,simno,tpos,tend,tide,WL,OL,id)
% This script will compare the spectra offshore in the model versus the
% spectra measured in the field.
% INPUT:
% savefolder: location where processed data will be saved
% simno: number of simulation that represents forcing
% tide:  tidal elevation put into SWASH simulation
% tpos:  start analysis
% tend:  end analysis
% WL:    Window length for calculated spectra, Steve=128, FRF=256
% OL:    Overlap length for calculated spectra, Steve=128*0.75, FRF = 128
% OUTPUT:
% sim:#_swash_offshore_spectra.mat = offshore spectra at specified location



% 
% clc
% clear all
% close all
% addpath(genpath('/data2/baker/SWASH/BATHYDuck15/codes/SWASH_analysis'));
% addpath(genpath('/data2/baker/MTOOLS'));
% frfpath  = '/data2/baker/Observations_BD15/data/';
% % path = '/Users/cmbaker9/Documents/Research/SWASH/BATHYDuck/';
% path  = '/data2/baker/SWASH/BATHYDuck15/';
% 
% %%%%%%%%%%%%%%%%%%%%%%%%% USER MODIFIABLE SECTION %%%%%%%%%%%%%%%%%%%%%%%%
% 
% % Simulation Details
% dateran= '19_04'; % month of simulation
% date   = '14-Oct-2015 23:00:00'; % date of forcing for simulation
% simno  = '30';    % arbritrary number that helps name simulations related to date
% time   = '7200'; % simulation time
% layers = 5;      % number of layers in simulation
% tide   = 0.151;  % tidal elevation in model run
% tpos   = 3601;   % start time for calculating time-averages parameters
% tend   = 7200;   % end time for calculating time-averages parameters (normally length of simulation or 1 sec less)
% fdomno = 2;      % number of .mat files the full domain is seperated in
% subno  = 3;      % number of .mat files the subgrid is seperated in
% 
% 
% % Consistant simulation folder name (same for run and data)
% simfolder    = ['sim',simno,'_',date(1:2),'-',date(4:6),'-',date(8:11),'_',date(13:14),'00/'];
% % simfolder = 'shore-normal_waves/';
% 
% % Run: simulation output location
% subfolder = '';%[time,'_',num2str(layers),'_layers_PSlowvisc/']; 
% runfolder     = [path,'runs/',dateran,'/',simfolder,subfolder,''];
% 
% % Data: processed simulation output location
% ssubfolder = [subfolder,''];%['sim',simno,'_',date(1:2),'-',date(4:6),'-',date(8:11),'_',date(13:14),'00/'];
% %[time,'_',num2str(layers),'_layers/'];
% savefolder = [path,'data/',simfolder,ssubfolder];
% % savefolder = runfolder;
% 
% % Observations: location of processed observations to compare with swash simulations
% frfsubfolder = '';
% frffolder = [frfpath,frfsubfolder];
% 
% WL     = 256;    % Window length for calculated spectra, Steve=128, FRF=256
% OL     = 128;    % Overlap length for calculated spectra, Steve=128*0.75, FRF = 128













display('Start save_offshore_spectra.')

%% STEP 1: Load data
load([savefolder,'sim',simno,'_domain.mat']);
tic
load([savefolder,'sim',simno,'_waterlevel.mat']);
toc
load([frffolder,'onshore_point_measurements.mat']);
load([frffolder,'offshore_point_measurements.mat']);

%% STEP 2: Save name
sname1 = [savefolder,'sim',simno,'_spectra_offshore.mat'];
sname2 = [savefolder,'sim',simno,'_spectra_offshore_avg.mat'];
sname3 = [savefolder,'sim',simno,'_spectra_06.mat'];
sname4 = [savefolder,'sim',simno,'_spectra_nearshore.mat'];
sname5 = [savefolder,'sim',simno,'_spectra_nearshore_avg.mat'];

%% STEP 3: Fix domain

xp   = fliplr(900-xp)+50;
yp   = -244+yp;
wlev = fliplr(wlev);

% x = fliplr(900-xp)+50;
% y = -244+yp;
% x_actual = find(x(1,:)==950); % because this is fliplr
% x_loc = (length(x(1,:))+1)-x_actual;
% y_loc = y(:,1);%round((find(y(:,1)==max(y(:,1))))/2);

%% STEP 4: Calculate Modeled Spectra

x_loc = xp(1,end);
y_loc = yp(:,1);
xi    = find(xp(1,:)==x_loc(:,1));
yi    = find(yp(:,1)==y_loc(:,1));
dT      = 1;
z = squeeze(wlev(yi,xi,tpos:tend));%tpos:tend));
for i = 1:length(y_loc)
    clear checknans
    z(i,:) = z(i,:)-nanmean(z(i,:));
    checknans = sum(isnan(z(i,:)));
    if checknans > 0
        temp = find(~isnan(z(i,:)));
        display([num2str(checknans),'~NaNs in z'])
        [See_off(i,:),f_off] = pwelch(z(i,temp),WL,OL,128,1/dT);  %Uses Welch's periodogram method
    else
        [See_off(i,:),f_off] = pwelch(z(i,:),WL,OL,128,1/dT);  %Uses Welch's periodogram method
    end
    Hs_off(i,:) = 4*sqrt(trapz(f_off,See_off(i,:)));
    z_off(i,:) = z(i,:);
end

See_off_avg = nanmean(See_off,1);
Hs_off_avg  = nanmean(Hs_off,1);

%% STEP 5: Save data

eval(['save -v7.3 ',sname1,' See_off',' f_off',' Hs_off',' z_off',' checknans'])
eval(['save -v7.3 ',sname2,' See_off_avg',' f_off',' Hs_off_avg'])

clear See* Hs* z* yi xi x_loc y_loc z

%% STEP 5: Find location of 6 m instrument

x06 = Off.xy06(1,1);
y06 = Off.xy06(1,2);

% Find the index of the alongshore location of the mean instrument location
% This will also include two extra indicies on either side of the indicies
% that the mean instrument location is. This will help with calculating the
% vorticity.
A = repmat(x06,1,length(xp(1,:))); % make matrix of repeating y_mean values
[minValue,close_i]  = nanmin(abs(A-xp(1,:))); % find the location of the minimum dif between the y_mean and the alongshore coordinates
% make a 4x1 matrix of the indicies of the alongshore coordinates, centered
% around y_mean
if x06 < xp(1,close_i)
    xi = [close_i-1;close_i];
elseif x06 > xp(close_i,1)
    xi = [close_i;close_i+1];
end
% check that this is done right
x06
xpt = xp(1,xi)

clear A minValue close_i

A = repmat(y06,length(yp(:,1)),1); % make matrix of repeating y_mean values
[minValue,close_i]  = nanmin(abs(A-yp(:,1))); % find the location of the minimum dif between the y_mean and the alongshore coordinates
% make a 4x1 matrix of the indicies of the alongshore coordinates, centered
% around y_mean
if y06 < yp(close_i,1)
    yi = [close_i-1;close_i];
elseif y06 > yp(close_i,1)
    yi = [close_i;close_i+1];
end
% check that this is done right
y06
ypt = yp(yi,1)
dT      = 1;

for i = 1:length(ypt)
    for j = 1:length(xpt)
        clear checknans
        x_loc(i,j) = xp(yi(i),xi(j));
        y_loc(i,j) = yp(yi(i),xi(j));
        z_06(i,j,:) = squeeze(wlev(yi(i),xi(j),tpos:tend));%tpos:tend));
            z_06(i,j,:) = z_06(i,j,:)-nanmean(z_06(i,j,:));
            checknans = sum(isnan(z_06(i,:)));
            if checknans > 0
                temp = find(~isnan(z_06(i,j,:)));
                display([num2str(checknans),'~NaNs in z'])
                [See_06(i,j,:),f_06(i,j,:)] = pwelch(squeeze(z_06(i,j,temp)),WL,OL,128,1/dT);  %Uses Welch's periodogram method
            else
                [See_06(i,j,:),f_06(i,j,:)] = pwelch(squeeze(z_06(i,j,:)),WL,OL,128,1/dT);  %Uses Welch's periodogram method
            end
            Hs_06(i,j,:) = 4*sqrt(trapz(squeeze(f_06(i,j,:)),squeeze(See_06(i,j,:))));
    end
end
        See_06_avg = nanmean(nanmean(See_06,2),1);
        Hs_06_avg  = nanmean(nanmean(Hs_06,2),1);

%% STEP 6: Save data

eval(['save -v7.3 ',sname3,' See_06',' f_06',' Hs_06',' z_06',' checknans',' See_06_avg',' f_06',' Hs_06_avg'])

clear See* Hs* z* f* yi xi x_loc y_loc z

%% STEP 7: Find location of 6 m instrument

if ~isnum(id)
    onshore_inst=  {'11';'12';'13';'14';'21';'22';'23';'24';'83';'84'};
    
    for k = 1:length(onshore_inst)
        eval(['x',onshore_inst{k},'=On.x',onshore_inst{k}])
        eval(['y',onshore_inst{k},'=On.y',onshore_inst{k}])
        eval(['A = repmat(x',onshore_inst{k},',1,length(xp(1,:)));']) % make matrix of repeating y_mean values
        [minValue,close_i]  = nanmin(abs(A-xp(1,:))); % find the location of the minimum dif between the y_mean and the alongshore coordinates
        % make a 4x1 matrix of the indicies of the alongshore coordinates, centered
        % around y_mean
        if eval(['x',onshore_inst{k},' < xp(1,close_i)'])
            xi = [close_i-1;close_i];
        elseif eval(['x',onshore_inst{k},' > xp(1,close_i)'])
            xi = [close_i;close_i+1];
        end
        % check that this is done right
        eval(['x',onshore_inst{k}])
        xpt = xp(1,xi)
        clear A minValue close_i
        
        eval(['A = repmat(y',onshore_inst{k},',length(yp(:,1)),1);']) % make matrix of repeating y_mean values
        [minValue,close_i]  = nanmin(abs(A-yp(:,1))); % find the location of the minimum dif between the y_mean and the alongshore coordinates
        % make a 4x1 matrix of the indicies of the alongshore coordinates, centered
        % around y_mean
        if eval(['y',onshore_inst{k},' < yp(close_i,1)'])
            yi = [close_i-1;close_i];
        elseif eval(['y',onshore_inst{k},' > yp(close_i,1)'])
            yi = [close_i;close_i+1];
        end
        % check that this is done right
        eval(['y',onshore_inst{k}])
        ypt = yp(yi,1)
        clear A minValue close_i
        
        dT      = 1;
        
        for i = 1:length(ypt)
            for j = 1:length(xpt)
                x_loc(i,j) = xp(yi(i),xi(j));
                y_loc(i,j) = yp(yi(i),xi(j));
                z(i,j,:) = squeeze(wlev(yi(i),xi(j),tpos:tend));%tpos:tend));
                z(i,j,:) = z(i,j,:)-nanmean(z(i,j,:));
                checknans = sum(isnan(z(i,:)));
                if checknans > 0
                    temp = find(~isnan(z(i,j,:)));
                    display([num2str(checknans),'~NaNs in z'])
                    [See(i,j,:),f(i,j,:)] = pwelch(squeeze(z(i,j,temp)),WL,OL,128,1/dT);  %Uses Welch's periodogram method
                else
                    [See(i,j,:),f(i,j,:)] = pwelch(squeeze(z(i,j,:)),WL,OL,128,1/dT);  %Uses Welch's periodogram method
                end
                Hs(i,j,:) = 4*sqrt(trapz(squeeze(f(i,j,:)),squeeze(See(i,j,:))));
            end
        end
        See_avg = nanmean(nanmean(See,2),1);
        See_avg = squeeze(See_avg(1,1,:));
        Hs_avg  = nanmean(nanmean(Hs,2),1);
        eval(['p',onshore_inst{k},'.See = See'])
        eval(['p',onshore_inst{k},'.See_avg = See_avg'])
        eval(['p',onshore_inst{k},'.f = f'])
        eval(['p',onshore_inst{k},'.Hs = Hs'])
        eval(['p',onshore_inst{k},'.z = z'])
        eval(['p',onshore_inst{k},'.x = x',onshore_inst{k}])
        eval(['p',onshore_inst{k},'.y = y',onshore_inst{k}])
        eval(['p',onshore_inst{k},'.xi = xi'])
        eval(['p',onshore_inst{k},'.yi = yi'])
        %     eval(['p',onshore_inst{k},'.checknans = checknans'])
        clear See* Hs* z* f* yi xi x_loc y_loc z
    end
    
    
    %% STEP 8: Save data
    
    eval(['save -v7.3 ',sname4,' p11',' p12',' p13',' p14',' p21',' p22',' p23',' p24',' p83',' p84'])
end

display('Done save_offshore_spectra.')

end