function subvars = swashrun2varmatrix(runfolder,simno,layers,sub2proc)
% This function will reorganize the subgrid output from SWASH (output as a
% variable every section) into a 3D matrix. 
% INPUT: 
% runfolder - general folder where SWASH output is stored
% simno     - simulation number
% sub2proc  - subgrid processing in this function
% OUTPUT:
% subvars   - structure containing 3D matrices of subgride output
%   wlev    - waterlevel
%   zk      - elevation of layer boundaries
%   vel_u   - cross-shore velocity of each layer
%   vel_v   - alongshore velocity of each layer
%   vort    - vorticty of each layer
% Created by C. M. Baker, 03/25/2020. This is an adaption of the previous
% function (parent function here) that ran this all in one script. This
% transition to a subfunction was completed when adopting the function to
% be independent on the number of subgrids (trying to process 6 subgrids).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% BEGIN FN %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% STEP 0: Load subgrid files

subvars  = load([runfolder,'/BD15_sim',simno,'_subgrid',sub2proc,'_domain.mat']);
duck_wat = load([runfolder,'/BD15_sim',simno,'_subgrid',sub2proc,'_wat.mat']);
duck_u   = load([runfolder,'/BD15_sim',simno,'_subgrid',sub2proc,'_uk.mat']);
duck_v   = load([runfolder,'/BD15_sim',simno,'_subgrid',sub2proc,'_vk.mat']);
duck_z   = load([runfolder,'/BD15_sim',simno,'_subgrid',sub2proc,'_zk.mat']);

%% STEP 1: Define Dimensions

% File details
x       = length(subvars.Xp(1,:)); % size x-dimension
y       = length(subvars.Yp(:,1)); % size y-dimension

%% STEP 2: Create List of File Names

% List of file names
ducknames_watlev    = fieldnames(duck_wat); % Copy all file names from duck_wat
ducknames_u         = fieldnames(duck_u); % Copy all file names from duck_uv
ducknames_v         = fieldnames(duck_v);
ducknames_z         = fieldnames(duck_z);

%% STEP 3: Convert to 4D File

count = 0;
count2 = 0;
count3 = 0;

for i = 1:1:length(ducknames_watlev)-1
    count=count+1;
    eval(['subvars.wlev(:,:,',num2str(count),')=double(duck_wat.',char(ducknames_watlev{i}),');']);
    for j = 1:layers
        count2 = count2+1;
        eval(['subvars.vel_u(:,:,',num2str(j),',',num2str(count),')=double(duck_u.',char(ducknames_u{count2}),');']);
        eval(['subvars.vel_v(:,:,',num2str(j),',',num2str(count),')=double(duck_v.',char(ducknames_v{count2}),');']);
    end
    for k = 1:(layers+1)
        count3 = count3+1;
        eval(['subvars.zk(:,:,',num2str(k),',',num2str(count),')=double(duck_z.',char(ducknames_z{count3}),');']);
    end
end
clear i j

%% STEP 4: Calculate velocity

for k = 1:length(subvars.vel_v(1,1,1,:))
    for i = 1:length(subvars.vel_v(1,1,:,1))
        subvars.vort(:,:,i,k) = curl(subvars.Xp,subvars.Yp,subvars.vel_u(:,:,i,k),subvars.vel_v(:,:,i,k));
    end
end

clear k i

display(['Done with subgrid ',sub2proc])
